#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
	Zajem je program za skeniranje in opremljanje dokumentov z atributi.
    Copyright (C) 2013  Mladen Kuntner (mladen.kuntner@triera.net)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

import sys
import os
import datetime
import decimal
import copy
import subprocess
import shutil
import crypt
import time
import sqlite3
from PyQt4 import QtCore,QtGui
import pkgutil
import importlib
import PluginsExport
import PluginsDatabase

# ********************************************************************************************
# dialog za prikaz napak
# ********************************************************************************************
class NapakaDialog(QtGui.QDialog):
	def __init__(self,parrent,napaka):
		super(NapakaDialog, self).__init__(parrent)
		layout = QtGui.QVBoxLayout()
		self.setWindowTitle(u" - Napaka! - ")
		self.setSizeGripEnabled(False)
		self.setStyleSheet("QDialog { background-color: %s }" %QtGui.QColor(230,150,150).name())
		layout.addWidget(QtGui.QLabel(napaka))
		napakaGumb = QtGui.QPushButton("Zapri")
		napakaGumb.clicked.connect(self.done,0)
		napakaGumb.setDefault(True)
		layout.addWidget(napakaGumb)
		self.setLayout(layout)

# ********************************************************************************************
# dialog za prikaz napredka posamznih opravil pri izvozu
# ********************************************************************************************
class IzvozDialog(QtGui.QDialog):
	def __init__(self,parrent):
		super(IzvozDialog, self).__init__(parrent)
		layout = QtGui.QVBoxLayout()
		self.setWindowTitle(u"Izvoz dokumentov")
		self.setSizeGripEnabled(False)
		self.setStyleSheet("QDialog { background-color: %s }" %QtGui.QColor(150,230,150).name())
		layout.addWidget(QtGui.QLabel("Prepoznava besedila"))
		self.prepoznavaProgressBar = QtGui.QProgressBar()
		self.prepoznavaProgressBar.setFormat("Dokument %v od %m")
		layout.addWidget(self.prepoznavaProgressBar)
		glavnoOkno.izvoziDokumenteThread.prepoznavaSkupajSignal.connect(self.prepoznavaSkupaj)
		glavnoOkno.izvoziDokumenteThread.prepoznavaNaslednjiSignal.connect(self.prepoznavaNaslednji)
		layout.addWidget(QtGui.QLabel("Pretvorba pnm -> tif"))
		self.pnm2tifProgressBar = QtGui.QProgressBar()
		self.pnm2tifProgressBar.setFormat("Dokument %v od %m")
		layout.addWidget(self.pnm2tifProgressBar)
		glavnoOkno.izvoziDokumenteThread.pnm2tifSkupajSignal.connect(self.pnm2tifSkupaj)
		glavnoOkno.izvoziDokumenteThread.pnm2tifNaslednjiSignal.connect(self.pnm2tifNaslednji)
		layout.addWidget(QtGui.QLabel("Pretvorba single page -> multi page"))
		self.single2multiProgressBar = QtGui.QProgressBar()
		self.single2multiProgressBar.setFormat("Dokument %v od %m")
		layout.addWidget(self.single2multiProgressBar)
		glavnoOkno.izvoziDokumenteThread.single2multiSkupajSignal.connect(self.single2multiSkupaj)
		glavnoOkno.izvoziDokumenteThread.single2multiNaslednjiSignal.connect(self.single2multiNaslednji)
		layout.addWidget(QtGui.QLabel("Pretvorba tif -> pdf"))
		self.tif2pdfProgressBar = QtGui.QProgressBar()
		self.tif2pdfProgressBar.setFormat("Dokument %v od %m")
		layout.addWidget(self.tif2pdfProgressBar)
		glavnoOkno.izvoziDokumenteThread.tif2pdfSkupajSignal.connect(self.tif2pdfSkupaj)
		glavnoOkno.izvoziDokumenteThread.tif2pdfNaslednjiSignal.connect(self.tif2pdfNaslednji)
		layout.addWidget(QtGui.QLabel("Izvoz"))
		self.izvozProgressBar = QtGui.QProgressBar()
		self.izvozProgressBar.setFormat("Dokument %v od %m")
		layout.addWidget(self.izvozProgressBar)
		glavnoOkno.izvoziDokumenteThread.izvozSkupajSignal.connect(self.izvozSkupaj)
		glavnoOkno.izvoziDokumenteThread.izvozNaslednjiSignal.connect(self.izvozNaslednji)
		zapriButton = QtGui.QPushButton(u"Zapri")
		zapriButton.clicked.connect(self.close)
		layout.addWidget(zapriButton)
		self.setLayout(layout)

	def prepoznavaSkupaj(self,vrednost):
		self.prepoznavaProgressBar.setMinimum(0)
		self.prepoznavaProgressBar.setMaximum(vrednost)
		self.prepoznavaProgressBar.setValue(0)
		
	def prepoznavaNaslednji(self):
		self.prepoznavaProgressBar.setValue(self.prepoznavaProgressBar.value() + 1)

	def pnm2tifSkupaj(self,vrednost):
		self.pnm2tifProgressBar.setMinimum(0)
		self.pnm2tifProgressBar.setMaximum(vrednost)
		self.pnm2tifProgressBar.setValue(0)
		
	def pnm2tifNaslednji(self):
		self.pnm2tifProgressBar.setValue(self.pnm2tifProgressBar.value() + 1)

	def single2multiSkupaj(self,vrednost):
		self.single2multiProgressBar.setMinimum(0)
		self.single2multiProgressBar.setMaximum(vrednost)
		self.single2multiProgressBar.setValue(0)
		
	def single2multiNaslednji(self):
		self.single2multiProgressBar.setValue(self.single2multiProgressBar.value() + 1)

	def tif2pdfSkupaj(self,vrednost):
		self.tif2pdfProgressBar.setMinimum(0)
		self.tif2pdfProgressBar.setMaximum(vrednost)
		self.tif2pdfProgressBar.setValue(0)
		
	def tif2pdfNaslednji(self):
		self.tif2pdfProgressBar.setValue(self.tif2pdfProgressBar.value() + 1)

	def izvozSkupaj(self,vrednost):
		self.izvozProgressBar.setMinimum(0)
		self.izvozProgressBar.setMaximum(vrednost)
		self.izvozProgressBar.setValue(0)
		
	def izvozNaslednji(self):
		self.izvozProgressBar.setValue(self.izvozProgressBar.value() + 1)

# ********************************************************************************************
# validator za tip polja besedilo
# ********************************************************************************************
class BesediloValidator(QtGui.QValidator):
	def __init__(self):
		super(BesediloValidator, self).__init__()

	def validate(self,vnos,kurzor):
		if not vnos:
			return (QtGui.QValidator.Intermediate,vnos,kurzor)
		return (QtGui.QValidator.Acceptable,vnos,kurzor)

# ********************************************************************************************
# validator za tip polja datum
# ********************************************************************************************
class DatumValidator(QtGui.QValidator):
	def __init__(self):
		super(DatumValidator, self).__init__()

	def validate(self,vnos,kurzor):
		tmpVnos = vnos.split(".")
		try:
			datetime.date(int(tmpVnos[2]),int(tmpVnos[1]),int(tmpVnos[0]))
		except ValueError:
			return (QtGui.QValidator.Intermediate,vnos,kurzor)
		return (QtGui.QValidator.Acceptable,vnos,kurzor)

# ********************************************************************************************
# validator za tip polja vrednost - decimalna števila s predznakom, decimalno vejico
# ********************************************************************************************
class VrednostValidator(QtGui.QValidator):
	def __init__(self):
		super(VrednostValidator, self).__init__()
		self.dovoljeniZnaki = ("1","2","3","4","5","6","7","8","9","0","+","-",",")

	def validate(self,vnos,kurzor):
		tmpVnos = ''
		for c in vnos:
			if c in self.dovoljeniZnaki:
				tmpVnos += c
		try:
			decimal.Decimal(tmpVnos.replace(",","."))
		except decimal.InvalidOperation:
			return (QtGui.QValidator.Intermediate,tmpVnos,kurzor)
		return (QtGui.QValidator.Acceptable,tmpVnos,kurzor)

# ********************************************************************************************
# okno za predogled dokumentov z autoScroll sposobnostjo
# ********************************************************************************************
class AutoScrollWidget(QtGui.QWidget):
	def __init__(self):
		super(AutoScrollWidget, self).__init__()
		self.autoScroll = False
		
	def resizeEvent(self,event):
		if self.autoScroll:
			glavnoOkno.scrollArea.horizontalScrollBar().setValue(glavnoOkno.scrollArea.horizontalScrollBar().maximum())

# ********************************************************************************************
# ClickLabel je slika poskeniranega dokumenta, ki ob kliku na sliko naredi ocr v prvo polje
# ********************************************************************************************
class ClickLabel(QtGui.QLabel):
	def __init__(self):
		super(ClickLabel, self).__init__()
		self.delta = 10 # kdaj se klik smatra kot select
		self.x0 = 0
		self.y0 = 0
		self.x1 = 0
		self.y1 = 0
		self.xMax = 0
		self.yMax = 0
		
	def mousePressEvent(self,event):
		self.x0 = event.x()
		self.y0 = event.y()

	def mouseReleaseEvent(self,event):
		self.x1 = event.x()
		self.y1 = event.y()
		self.pripravi(event)

	# pogledamo ali je uporabnik izbral območje za OCR ali pa samo kliknil na sliko 
	def pripravi(self,event):
		self.xMax = self.pixmap().width()
		self.yMax = self.pixmap().height()
		if (abs(self.x0 - self.x1) > self.delta) and (abs(self.y0 - self.y1) > self.delta): # uporabnik je izbral območje za OCR
			tmpX0 = 100 * self.x0 / self.xMax # tmp spremenljivke so v procentih velikosti skena
			tmpY0 = 100 * self.y0 / self.yMax
			tmpX1 = 100 * self.x1 / self.xMax
			tmpY1 = 100 * self.y1 / self.yMax
		else:
			if ( QtCore.Qt.LeftButton == event.button() ): # uporabnik je izbral levi zgornji rob območja za OCR
				tmpX0 = 100 * self.x0 / self.xMax
				tmpY0 = 100 * self.y0 / self.yMax
				tmpX1 = decimal.Decimal(tmpX0) + decimal.Decimal(glavnoOkno.sirinaOcr)
				tmpY1 = decimal.Decimal(tmpY0) + decimal.Decimal(glavnoOkno.visinaOcr)
			if ( QtCore.Qt.RightButton == event.button() ): # za OCR uporabi privzete nastavitve
				tmpX0 = decimal.Decimal(glavnoOkno.xOcr)
				tmpY0 = decimal.Decimal(glavnoOkno.yOcr)
				tmpX1 = tmpX0 + decimal.Decimal(glavnoOkno.sirinaOcr)
				tmpY1 = tmpY0 + decimal.Decimal(glavnoOkno.visinaOcr)
		self.preberi(min(tmpX0 , tmpX1),min(tmpY0 , tmpY1),max(tmpX0 , tmpX1),max(tmpY0 , tmpY1))

	# naredimo OCR izbranega območja slike, parametri so v procentih
	def preberi(self,procentX0,procentY0,procentX1,procentY1):
		skenDatoteka = glavnoOkno.skenDirektorijTip + glavnoOkno.skenDatoteka
		ocrDatoteka = glavnoOkno.povecavaDirektorij + "/" + "ocr.pnm"
		textDatoteka = glavnoOkno.povecavaDirektorij + "/" + "text"
		tmpPixmap = QtGui.QPixmap(skenDatoteka)
		sirina = tmpPixmap.width()
		visina = tmpPixmap.height()
		ocrX0 = round(procentX0 * sirina / 100)
		ocrY0 = round(procentY0 * visina / 100)
		ocrX1 = round(procentX1 * sirina / 100)
		ocrY1 = round(procentY1 * visina / 100)
		ocrDatotekaFD = open(ocrDatoteka ,"w")
		subprocess.call(["pamcut","-left",str(ocrX0),"-top",str(ocrY0),"-right",str(ocrX1),"-bottom",str(ocrY1),skenDatoteka], stdout = ocrDatotekaFD)
		ocrDatotekaFD.close()
		if "Tesseract" == glavnoOkno.poljeOcr:
			subprocess.call(["tesseract","-l",glavnoOkno.tesseractJezik,ocrDatoteka,textDatoteka])
			try:
				textDatotekaFD = open(textDatoteka + ".txt" ,"r")
				prebrano = textDatotekaFD.read()
				textDatotekaFD.close()
			except OSError:
				prebrano = ""
		if "Cuneiform" == glavnoOkno.poljeOcr:
			subprocess.call(["cuneiform","-l",glavnoOkno.cuneiformJezik,"-o",textDatoteka + ".txt",ocrDatoteka])
			try:
				textDatotekaFD = open(textDatoteka + ".txt","r")
				prebrano = textDatotekaFD.read()
				textDatotekaFD.close()
			except OSError:
				prebrano = ""
		glavnoOkno.podatkiFormLayout.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setText(prebrano.strip())
		glavnoOkno.podatkiFormLayout.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setFocus()
		try:
			os.remove(textDatoteka + ".txt")
		except OSError:
			pass

# ********************************************************************************************
# gumb ki služi kot predogled dokumenta
# in se obarva pri izbiri in povezavi
# ********************************************************************************************
class ThumbnailToolButton(QtGui.QToolButton):
	def __init__(self,sken):
		super(ThumbnailToolButton, self).__init__()
		self.barvaOzadjaIzbran = QtGui.QColor(230,20,20)
		self.barvaOzadjaNiIzbran = QtGui.QColor(230,230,230)
		barvaOzadjaSpet1 = QtGui.QColor(30,240,30)
		barvaOzadjaSpet2 = QtGui.QColor(180,220,0)
		barvaOzadjaSpet3 = QtGui.QColor(0,220,180)
		self.barve = [barvaOzadjaSpet1.name(),barvaOzadjaSpet2.name(),barvaOzadjaSpet3.name()]
		self.spet = 0 # 0 pomeni da ni spet , 1 2 3 pomeni da je spet
		self.dokumentList = [] # seznam listov s katerimi je spet v dokument
		self.izbran = False
		self.select = False
		self.dodajEnega = True
		self.setStyleSheet("QToolButton { background-color: %s }" %self.barvaOzadjaNiIzbran.name())
		self.setText(os.path.split(sken)[1].split(".")[0])
		ikona = QtGui.QIcon(sken)
		self.setIcon(ikona)
		self.setIconSize(ikona.availableSizes()[0])
		self.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
		self.setMinimumSize(self.sizeHint())

	# označi list kot izbran
	def setIzbran(self):
		self.izbran = True
		self.setStyleSheet("QToolButton { background-color: %s }" %self.barvaOzadjaIzbran.name())

	# označi list kot ne izbran
	def setNiIzbran(self):
		self.izbran = False
		if self.spet:
			self.setStyleSheet("QToolButton { background-color: %s }" %self.barve[self.spet-1])
		else:
			self.setStyleSheet("QToolButton { background-color: %s }" %self.barvaOzadjaNiIzbran.name())

	# označi list kot spet
	def spniList(self,barva):
		self.setNiIzbran()
		self.spet = barva
		self.setStyleSheet("QToolButton { background-color: %s }" %self.barve[barva-1])

	# označi list kot razpet
	def razpniList(self):
		self.setNiIzbran()
		self.spet = 0
		self.setStyleSheet("QToolButton { background-color: %s }" %self.barvaOzadjaNiIzbran.name())

	# postavi select in dodajEnega glede na to katere tipke (shift,ctrl) so pritisnjene
	# in katero tipko na miški je uporabnik kliknil
	def mousePressEvent(self,event):
		self.select = False
		if ( event.modifiers() & QtCore.Qt.ControlModifier ):
			self.select = True
			self.dodajEnega = True
		if ( event.modifiers() & QtCore.Qt.ShiftModifier ):
			self.select = True
			self.dodajEnega = False
		if ( QtCore.Qt.RightButton == event.button() ):
			self.select = True
			self.dodajEnega = False
			self.clicked.emit(True)
		QtGui.QToolButton.mousePressEvent(self,event)

# ********************************************************************************************
# poiščemo skener
# da se uporabniški vmesnik normalno nariše izvedemo kot thread
# ********************************************************************************************
class PoisciSkenerThread(QtCore.QThread):
	def __init__(self, parent = None):
		QtCore.QThread.__init__(self, parent)

	def run(self):
		# počakamo da se nariše grafični vmesnik
		while not 'glavnoOkno' in globals():
			time.sleep(0.1)
		# poisci skener preko sane
		saneSkenerDatotekaFD = open(glavnoOkno.configDirektorij + "/" + "saneSkener.txt","w")
		subprocess.call(["sane-find-scanner","-q"], stdout = saneSkenerDatotekaFD)
		saneSkenerDatotekaFD.close()
		saneSkenerDatotekaFD = open(glavnoOkno.configDirektorij + "/" + "saneSkener.txt","r")
		saneSkener = saneSkenerDatotekaFD.read()
		saneSkenerDatotekaFD.close()
		# poisci skener preko scanimage
		scanimageSkenerDatotekaFD = open(glavnoOkno.configDirektorij + "/" + "scanimageSkener.txt","w")
		subprocess.call(["scanimage","-f%d %v %m %n"], stdout = scanimageSkenerDatotekaFD)
		scanimageSkenerDatotekaFD.close()
		scanimageSkenerDatotekaFD = open(glavnoOkno.configDirektorij + "/" + "scanimageSkener.txt","r")
		scanimageSkener = scanimageSkenerDatotekaFD.read()
		scanimageSkenerDatotekaFD.close()
		scanimageSkenerList = scanimageSkener.split("\n")
		# sane-find-scanner najde samo skenerje
		# scanimage -f najde tudi druge naprave
		# zato vzamemo usb-id od sane-find-scanner in glede na to poiščemo id in name skenerja
		# v listi naprav ki je vrnil scanimage
		saneUsbIdSplit = saneSkener.split()
		if saneUsbIdSplit:
			saneUsbId = saneUsbIdSplit[-1]
			for tmpSkener in scanimageSkenerList:
				if saneUsbId in tmpSkener:
					scanimageSkenerFound = tmpSkener.split(" ",1)
			glavnoOkno.skenerId = scanimageSkenerFound[0]
			glavnoOkno.skenerName = scanimageSkenerFound[1].strip()
			# shranimo vse možne nastavitve za skener v datoteko
			scanimageAllDatotekaFD = open(glavnoOkno.configDirektorij + "/" + glavnoOkno.skenerName + ".txt","w")
			subprocess.call(["scanimage","-d",glavnoOkno.skenerId,"-A"], stdout = scanimageAllDatotekaFD)
			scanimageAllDatotekaFD.close()
			scanimageAllDatotekaFD = open(glavnoOkno.configDirektorij + "/" + glavnoOkno.skenerName + ".txt","r")
			scanimageSkenerAll = scanimageAllDatotekaFD.read()
			scanimageSkenerAllList = scanimageSkenerAll.split("\n")
			scanimageAllDatotekaFD.close()
			glavnoOkno.poisciNastavitveSkenerja()
		else:
			glavnoOkno.skenerId = None
			glavnoOkno.skenerName = None

# ********************************************************************************************
# skeniramo en list
# da lahko uporabnik vidi status programa izvedemo kot thread
# ********************************************************************************************
class SkenirajEnListThread(QtCore.QThread):
	def __init__(self, parent = None):
		QtCore.QThread.__init__(self, parent)

	def run(self):
		imeDatoteke = "{0:04d}.pnm".format(glavnoOkno.steviloSkenov)
		skenDirektorijTip =  glavnoOkno.skenDirektorij + "/" + glavnoOkno.tipDokumenta + "/"
		if not os.path.isdir(skenDirektorijTip):
			os.makedirs(skenDirektorijTip)
		thumbnailDirektorijTip = glavnoOkno.thumbnailDirektorij + "/" + glavnoOkno.tipDokumenta + "/"
		if not os.path.isdir(thumbnailDirektorijTip):
			os.makedirs(thumbnailDirektorijTip)
		skenDatoteka = skenDirektorijTip + imeDatoteke
		skenDatotekaFD = open(skenDatoteka,"w")
		scanimageStatusFD = open(glavnoOkno.configDirektorij + "/" + "scanimageStatus.txt","w")
		skenOpcije = ["scanimage","-d",glavnoOkno.skenerId]
		if glavnoOkno.skenString:
			skenOpcije.extend(glavnoOkno.skenString)
		subprocess.call(skenOpcije, stdout = skenDatotekaFD, stderr = scanimageStatusFD)
		scanimageStatusFD.close()
		skenDatotekaFD.close()
		scanimageStatusDatoteka = open(glavnoOkno.configDirektorij + "/" + "scanimageStatus.txt","r")
		scanimageStatus = scanimageStatusDatoteka.read()
		scanimageStatusDatoteka.close()
		# če je bilo vse v redu je statusna datoteke prazna
		if not scanimageStatus:
			thumbnailDatoteka = thumbnailDirektorijTip + imeDatoteke
			thumbnailDatotekaFD = open(thumbnailDatoteka,"w")
			errorDatotekaFD = open(glavnoOkno.configDirektorij + "/" + "error.log","w")
			subprocess.call(["pamscale","0.0625",skenDatoteka], stdout = thumbnailDatotekaFD, stderr = errorDatotekaFD)
			thumbnailDatotekaFD.close()
			errorDatotekaFD.close()
			glavnoOkno.steviloSkenov += 1

# ********************************************************************************************
# skeniramo vse liste v podajalcu
# da lahko uporabnik vidi status programa izvedemo kot thread
# ********************************************************************************************
class SkenirajVseListeThread(QtCore.QThread):
	def __init__(self, parent = None):
		QtCore.QThread.__init__(self, parent)

	def run(self):
		skenDirektorijTip = glavnoOkno.skenDirektorij + "/" + glavnoOkno.tipDokumenta + "/"
		if not os.path.isdir(skenDirektorijTip):
			os.makedirs(skenDirektorijTip)
		thumbnailDirektorijTip = glavnoOkno.thumbnailDirektorij + "/" + glavnoOkno.tipDokumenta + "/"
		if not os.path.isdir(thumbnailDirektorijTip):
			os.makedirs(thumbnailDirektorijTip)
		scanimageStatusDatoteka = open(glavnoOkno.configDirektorij + "/" + "scanimageStatus.txt","w")
		skenOpcije = ["scanimage","-d",glavnoOkno.skenerId,"--batch=" + skenDirektorijTip +"%04d.pnm","--batch-start",str(glavnoOkno.steviloSkenov)]
		if glavnoOkno.skenString:
			skenOpcije.extend(glavnoOkno.skenString)
		subprocess.call(skenOpcije, stderr = scanimageStatusDatoteka)
		scanimageStatusDatoteka.close()
		# iz statusne datoteke, ki jo je naredil scanimage pogledamo katera je zadnja poskenirana stran
		scanimageStatusDatoteka = open(glavnoOkno.configDirektorij + "/" + "scanimageStatus.txt","r")
		scanimageStatus = scanimageStatusDatoteka.read()
		scanimageStatusDatoteka.close()
		scanimageStatusList = scanimageStatus.split("\n")
		zadnjaStranStatus = ""
		for statusLine in scanimageStatusList:
			if "Scanned page" in statusLine:
				zadnjaStranStatus = statusLine
		if zadnjaStranStatus:
			zadnjaStranList = zadnjaStranStatus.split()
			zadnjaStran = int(zadnjaStranList[2].strip("."))
			# naredimo thumbnaile
			for n in range(glavnoOkno.steviloSkenov,zadnjaStran + 1):
				indeks = "{0:04d}".format(n)
				errorDatotekaFD = open(glavnoOkno.configDirektorij + "/" + "error.log","w")
				thumbnailDatoteka = open(thumbnailDirektorijTip + indeks + ".pnm","w")
				subprocess.call(["pamscale","0.0625",skenDirektorijTip + indeks + ".pnm"], stdout = thumbnailDatoteka, stderr = errorDatotekaFD)
				thumbnailDatoteka.close()
				errorDatotekaFD.close()
			glavnoOkno.steviloSkenov = zadnjaStran +1

# ********************************************************************************************
# izvozimo vse povezane dokumente
# da lahko uporabnik vidi status programa izvedemo kot thread
# ********************************************************************************************
class IzvoziDokumenteThread(QtCore.QThread):
	prepoznavaSkupajSignal = QtCore.pyqtSignal(int)
	prepoznavaNaslednjiSignal = QtCore.pyqtSignal()
	pnm2tifSkupajSignal = QtCore.pyqtSignal(int)
	pnm2tifNaslednjiSignal = QtCore.pyqtSignal()
	single2multiSkupajSignal = QtCore.pyqtSignal(int)
	single2multiNaslednjiSignal = QtCore.pyqtSignal()
	tif2pdfSkupajSignal = QtCore.pyqtSignal(int)
	tif2pdfNaslednjiSignal = QtCore.pyqtSignal()
	izvozSkupajSignal = QtCore.pyqtSignal(int)
	izvozNaslednjiSignal = QtCore.pyqtSignal()

	def __init__(self, parent = None):
		QtCore.QThread.__init__(self, parent)

	def run(self):
		dokumentiList = list(sorted(spisekDokumentov.keys()))
		dokumentiDirektorij = glavnoOkno.izvozDirektorij + "/" + "Dokumenti" # naredimo prazen direktorij za slike dokumentov
		if os.path.isdir(dokumentiDirektorij):
			shutil.rmtree(dokumentiDirektorij)
		os.makedirs(dokumentiDirektorij)
		# če je izbran OCR ga naredimo
		if glavnoOkno.tesseract or glavnoOkno.cuneiform:
			ocriExportList = []
			self.prepoznavaSkupajSignal.emit(len(dokumentiList))
			for dokument in dokumentiList:
				tmpOcriList = []
				for stran in range(dokument[0],dokument[1] + 1):
					indeks = glavnoOkno.predogledLayout.itemAt(stran).widget().text()
					ocrDatoteka = glavnoOkno.skenDirektorijTip + "/" + indeks +".pnm"
					tessDatoteka = dokumentiDirektorij + "/" + glavnoOkno.tipDokumenta + "-" + indeks + "-tess"
					cuneDatoteka = dokumentiDirektorij + "/" + glavnoOkno.tipDokumenta + "-" + indeks + "-cune.txt"
					if glavnoOkno.tesseract:
						subprocess.call(["tesseract","-l",glavnoOkno.tesseractJezik,ocrDatoteka,tessDatoteka])
						tmpOcriList.append(tessDatoteka)
					if glavnoOkno.cuneiform:
						subprocess.call(["cuneiform","-l",glavnoOkno.cuneiformJezik,"-o",cuneDatoteka,ocrDatoteka])
						tmpOcriList.append(cuneDatoteka)
				ocriExportList.append(tmpOcriList)
				self.prepoznavaNaslednjiSignal.emit()
		# izvozimo slike dokumentov
		izvozList =[]
		if 1 == glavnoOkno.izvoz or 2 == glavnoOkno.izvoz or 3 == glavnoOkno.izvoz or 4 == glavnoOkno.izvoz: # pretvorimo pnm datoteke v tif
			dokumentiExportList = []
			self.pnm2tifSkupajSignal.emit(len(dokumentiList))
			for dokument in dokumentiList:
				tmpSlikeList = []
				tmpIndeksList = []
				for stran in range(dokument[0],dokument[1] + 1):
					indeks = glavnoOkno.predogledLayout.itemAt(stran).widget().text()
					tiffDatoteka = dokumentiDirektorij + "/" + glavnoOkno.tipDokumenta + "-" + indeks + ".tif"
					tiffDatotekaFD = open(tiffDatoteka,"w")
					subprocess.call(["pamtotiff","-flate",glavnoOkno.skenDirektorijTip + "/" + indeks +".pnm"], stdout = tiffDatotekaFD)
					tiffDatotekaFD.close()
					tmpSlikeList.append(tiffDatoteka)
					tmpIndeksList.append(indeks)
				izvozList.append((tmpIndeksList,tmpSlikeList))
				dokumentiExportList.append(tmpSlikeList)
				self.pnm2tifNaslednjiSignal.emit()
		if 2 == glavnoOkno.izvoz or 4 == glavnoOkno.izvoz: # pretvorimo tif datotege v multipage tif datoteke
			multipageList = []
			dokumentiExportList = []
			self.single2multiSkupajSignal.emit(len(izvozList))
			for dokument in izvozList:
				indeks = dokument[0][0] + "-" + dokument[0][-1]
				tiffDatoteka = dokumentiDirektorij + "/" + glavnoOkno.tipDokumenta + "-" + indeks + ".tif"
				tiffcpCallList = ["tiffcp"]
				tiffcpCallList.extend(dokument[1])
				tiffcpCallList.append(tiffDatoteka)
				subprocess.call(tiffcpCallList)
				for tmpFile in dokument[1]:
					os.remove(tmpFile)
				multipageList.append((indeks,tiffDatoteka))
				dokumentiExportList.append([tiffDatoteka])
				self.single2multiNaslednjiSignal.emit()
		if 3 == glavnoOkno.izvoz: # pretvorimo tif datoteke v pdf datoteke
			dokumentiExportList = []
			self.tif2pdfSkupajSignal.emit(len(izvozList))
			for dokument in izvozList:
				tmpExportList = []
				for i in range(0,len(dokument[0])):
					indeks = dokument[0][i]
					pdfDatoteka = dokumentiDirektorij + "/" + glavnoOkno.tipDokumenta + "-" + indeks + ".pdf"
					pdfDatotekaFD = open(pdfDatoteka,"w")
					subprocess.call(["tiff2pdf",dokument[1][i]], stdout = pdfDatotekaFD)
					pdfDatotekaFD.close()
					os.remove(dokument[1][i])
					tmpExportList.append(pdfDatoteka)
				dokumentiExportList.append(tmpExportList)
				self.tif2pdfNaslednjiSignal.emit()
		if 4 == glavnoOkno.izvoz: # pretvorimo multipage tif datoteke v multipage pdf datoteke
			dokumentiExportList = []
			self.tif2pdfSkupajSignal.emit(len(izvozList))
			for dokument in multipageList:
				indeks = dokument[0]
				pdfDatoteka = dokumentiDirektorij + "/" + glavnoOkno.tipDokumenta + "-" + indeks +".pdf"
				pdfDatotekaFD = open(pdfDatoteka,"w")
				subprocess.call(["tiff2pdf",dokument[1]], stdout = pdfDatotekaFD)
				pdfDatotekaFD.close()
				os.remove(dokument[1])
				dokumentiExportList.append([pdfDatoteka])
				self.tif2pdfNaslednjiSignal.emit()
		if glavnoOkno.izvozModul in glavnoOkno.exportModuliDict: # klic izvoz modula ki naredi export datoteko 
			podatkiExportList = []
			for dokument in dokumentiList:
				podatkiExportList.append(spisekDokumentov[dokument])
			glavnoOkno.exportModuliDict[glavnoOkno.izvozModul].izvoz(self,glavnoOkno.poljaDokumentaExportList,podatkiExportList,dokumentiExportList,ocriExportList)

# ********************************************************************************************
# widget za nastavitev podatkovnih polj za tip dokumenta
# ********************************************************************************************
class podatkiWidget(QtGui.QWidget):
	def __init__(self):
		super(podatkiWidget, self).__init__()
		podatkiLayout = QtGui.QVBoxLayout()
		tabelaInVpisWidget = QtGui.QWidget() # tabela in vpisna polja
		tabelaInVpisLayout = QtGui.QHBoxLayout()
		tabelaInVpisWidget.setLayout(tabelaInVpisLayout)
		self.tabelaWidget = QtGui.QTableWidget(1,2) # tabela
		self.tabelaWidget.setHorizontalHeaderLabels([u"Ime",u"Tip"])
		self.tabelaWidget.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
		self.tabelaWidget.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
		self.tabelaWidget.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
		self.tabelaWidget.cellClicked.connect(self.izbranaVrstica)
		tabelaInVpisLayout.addWidget(self.tabelaWidget)
		vpisWidget = QtGui.QWidget() # vpisna polja
		vpisLayout = QtGui.QFormLayout()
		vpisWidget.setLayout(vpisLayout)
		self.imeLineEdit = QtGui.QLineEdit()
		self.imeLineEdit.setEnabled(False)
		vpisLayout.addRow(u"Ime:",self.imeLineEdit)
		self.tipiComboBox = QtGui.QComboBox()
		self.tipiComboBox.setEnabled(False)
		self.tipiComboBox.addItems([u"Besedilo",u"Vrednost",u"Datum"])
		vpisLayout.addRow(u"Tip:",self.tipiComboBox)
		tabelaInVpisLayout.addWidget(vpisWidget)
		podatkiLayout.addWidget(tabelaInVpisWidget)
		gumbiWidget = QtGui.QWidget() # gumbi
		gumbiLayout = QtGui.QHBoxLayout()
		gumbiWidget.setLayout(gumbiLayout)
		self.novButton = QtGui.QPushButton(u"Nov")
		self.novButton.clicked.connect(self.novoPolje)
		gumbiLayout.addWidget(self.novButton)
		self.dodajButton = QtGui.QPushButton(u"Dodaj")
		self.dodajButton.clicked.connect(self.dodajPolje)
		self.dodajButton.setEnabled(False)
		gumbiLayout.addWidget(self.dodajButton)
		self.odstraniButton = QtGui.QPushButton(u"Odstrani")
		self.odstraniButton.clicked.connect(self.odstraniPolje)
		self.odstraniButton.setEnabled(False)
		gumbiLayout.addWidget(self.odstraniButton)
		podatkiLayout.addWidget(gumbiWidget)
		self.setLayout(podatkiLayout)

	# omogoči vnosna polja
	def omogociVnos(self):
		self.novButton.setEnabled(False)
		self.dodajButton.setEnabled(True)
		self.odstraniButton.setEnabled(False)
		self.imeLineEdit.setEnabled(True)
		self.imeLineEdit.setFocus()
		self.tipiComboBox.setEnabled(True)

	# onemogoči vnosna polja
	def onemogociVnos(self):
		self.novButton.setEnabled(True)
		self.dodajButton.setEnabled(False)
		self.odstraniButton.setEnabled(False)
		self.imeLineEdit.setText("")
		self.imeLineEdit.setEnabled(False)
		self.tipiComboBox.setEnabled(False)

	# uporabnik je izbral vrstico v tabeli
	def izbranaVrstica(self,vrstica,stolpec):
		if self.tabelaWidget.rowCount() -1 != vrstica:
			self.imeLineEdit.setText(self.tabelaWidget.item(vrstica,0).text())
			self.omogociVnos()
			self.dodajButton.setText(u"Spremeni")
			self.odstraniButton.setEnabled(True)
		else: # uporabnik je izbral prazno vrstico
			self.onemogociVnos()
			self.dodajButton.setText(u"Dodaj")
			self.tabelaWidget.clearSelection()
			self.tabelaWidget.setCurrentCell(-1,-1)

	# gumb Nov - pripravi vse za vnos novega polja
	def novoPolje(self):
		self.omogociVnos()

	# gumb Dodaj - doda polje v seznam polj
	def dodajPolje(self):
		if self.imeLineEdit.text():
			if -1 == self.tabelaWidget.currentRow(): # doda novo vrstico
				vrstica = self.tabelaWidget.rowCount() - 1
				self.tabelaWidget.setItem(vrstica,0,QtGui.QTableWidgetItem(self.imeLineEdit.text()))
				self.tabelaWidget.setItem(vrstica,1,QtGui.QTableWidgetItem(self.tipiComboBox.currentText()))
				self.tabelaWidget.setRowCount(self.tabelaWidget.rowCount() + 1)
				self.tabelaWidget.scrollToBottom()
				self.onemogociVnos()
			else: # spremeni izbrano vrstico
				vrstica = self.tabelaWidget.currentRow()
				self.tabelaWidget.setItem(vrstica,0,QtGui.QTableWidgetItem(self.imeLineEdit.text()))
				self.tabelaWidget.setItem(vrstica,1,QtGui.QTableWidgetItem(self.tipiComboBox.currentText()))
				self.tabelaWidget.clearSelection()
				self.tabelaWidget.setCurrentCell(-1,-1)
				self.dodajButton.setText(u"Dodaj")
				self.onemogociVnos()
		else:
			napakaDialog = NapakaDialog(self,"Ime polja mora biti vpisano!")
			napakaDialog.exec_()

	# gumb Odstrani - pripravi vse za vnos novega polja
	def odstraniPolje(self):
		self.tabelaWidget.removeRow(self.tabelaWidget.currentRow())
		self.tabelaWidget.clearSelection()
		self.tabelaWidget.setCurrentCell(-1,-1)
		self.dodajButton.setText(u"Dodaj")
		self.onemogociVnos()

# ********************************************************************************************
# widget za nastavitev načina skeniranja za ta tip dokumenta
# ********************************************************************************************
class skeniranjeWidget(QtGui.QWidget):
	def __init__(self):
		super(skeniranjeWidget, self).__init__()
		skeniranjeLayout = QtGui.QHBoxLayout()
		tabelaWidget = QtGui.QWidget()
		tabelaLayout = QtGui.QFormLayout()
		tabelaWidget.setLayout(tabelaLayout)
		self.skenerComboBox = QtGui.QComboBox()
		tabelaLayout.addRow(QtGui.QLabel("Skener:"),self.skenerComboBox)
		bazaUkaz = baza.cursor()
		skenerji = bazaUkaz.execute("SELECT skener FROM Skenerji").fetchall()
		for skener in skenerji:
			self.skenerComboBox.addItem(skener[0])
		self.profilComboBox = QtGui.QComboBox()
		tabelaLayout.addRow(QtGui.QLabel("Profil:"),self.profilComboBox)
		bazaUkaz = baza.cursor()
		profili = bazaUkaz.execute("SELECT profil FROM Profili").fetchall()
		for profil in profili:
			self.profilComboBox.addItem(profil[0])
		skeniranjeLayout.addWidget(tabelaWidget)
		skeniranjeLayout.addStretch(1)
		self.setLayout(skeniranjeLayout)

# ********************************************************************************************
# widget za nastavitev povezovanja listov v dokument
# ********************************************************************************************
class povezovanjeWidget(QtGui.QWidget):
	def __init__(self):
		super(povezovanjeWidget, self).__init__()
		povezovanjeLayout = QtGui.QVBoxLayout()
		rocnoRadioButton = QtGui.QRadioButton(u"Ročno")
		polavtomatskoRadioButton = QtGui.QRadioButton(u"Polavtomatsko")
		crtnakodaRadioButton = QtGui.QRadioButton(u"Polavtomatsko - črtna koda")
		prepoznavanjeRadioButton = QtGui.QRadioButton(u"Polavtomatsko - prepoznavanje besedila")
		povezovanjeLayout.addWidget(rocnoRadioButton)
		povezovanjeLayout.addWidget(polavtomatskoRadioButton)
		povezovanjeLayout.addWidget(crtnakodaRadioButton)
		povezovanjeLayout.addWidget(prepoznavanjeRadioButton)
		self.povezovanjeButtonGroup = QtGui.QButtonGroup(self)
		self.povezovanjeButtonGroup.addButton(rocnoRadioButton,1)
		self.povezovanjeButtonGroup.addButton(polavtomatskoRadioButton,2)
		self.povezovanjeButtonGroup.addButton(crtnakodaRadioButton,3)
		self.povezovanjeButtonGroup.addButton(prepoznavanjeRadioButton,4)
		rocnoRadioButton.setChecked(True)
		povezovanjeWidget_1 = QtGui.QWidget()
		povezovanjeLayout_1 = QtGui.QFormLayout()
		povezovanjeLayout_1.setSizeConstraint(QtGui.QLayout.SetFixedSize)
		povezovanjeWidget_1.setLayout(povezovanjeLayout_1)
		self.povezovanjeComboBox = QtGui.QComboBox()
		self.povezovanjeComboBox.addItem(u"Brez")
		self.povezovanjeComboBox.addItems(list(sorted(glavnoOkno.databaseModuliDict.keys())))
		povezovanjeLayout_1.addRow(QtGui.QLabel("Database modul:"),self.povezovanjeComboBox)
		povezovanjeLayout.addWidget(povezovanjeWidget_1)
		self.setLayout(povezovanjeLayout)

# ********************************************************************************************
# widget za nastavitev izvoza
# ********************************************************************************************
class izvozWidget(QtGui.QWidget):
	def __init__(self):
		super(izvozWidget, self).__init__()
		izvozLayout = QtGui.QVBoxLayout()
		enostranskiTiffRadioButton = QtGui.QRadioButton(u"enostranski TIFF")
		vecstranskiTiffRadioButton = QtGui.QRadioButton(u"večstranski TIFF")
		enostranskiPdfRadioButton = QtGui.QRadioButton(u"enostranski PDF")
		vecstranskiPdfRadioButton = QtGui.QRadioButton(u"večstranski PDF")
		izvozLayout.addWidget(enostranskiTiffRadioButton)
		izvozLayout.addWidget(vecstranskiTiffRadioButton)
		izvozLayout.addWidget(enostranskiPdfRadioButton)
		izvozLayout.addWidget(vecstranskiPdfRadioButton)
		self.izvozButtonGroup = QtGui.QButtonGroup(self)
		self.izvozButtonGroup.addButton(enostranskiTiffRadioButton,1)
		self.izvozButtonGroup.addButton(vecstranskiTiffRadioButton,2)
		self.izvozButtonGroup.addButton(enostranskiPdfRadioButton,3)
		self.izvozButtonGroup.addButton(vecstranskiPdfRadioButton,4)
		enostranskiTiffRadioButton.setChecked(True)
		izvoziWidget_1 = QtGui.QWidget()
		izvozLayout_1 = QtGui.QFormLayout()
		izvozLayout_1.setSizeConstraint(QtGui.QLayout.SetFixedSize)
		izvoziWidget_1.setLayout(izvozLayout_1)
		self.izvoziComboBox = QtGui.QComboBox()
		self.izvoziComboBox.addItem(u"Brez")
		self.izvoziComboBox.addItems(list(sorted(glavnoOkno.exportModuliDict.keys())))
		izvozLayout_1.addRow(QtGui.QLabel("Izvoz modul:"),self.izvoziComboBox)
		izvozLayout.addWidget(izvoziWidget_1)
		self.setLayout(izvozLayout)

# ********************************************************************************************
# widget za izbiro prepoznave črtne kode
# ********************************************************************************************
class crtnaKodaWidget(QtGui.QWidget):
	def __init__(self):
		super(crtnaKodaWidget, self).__init__()
		self.crtnaKodaLayout = QtGui.QVBoxLayout()
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"ean13"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"ean8"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"upca"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"upce"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"isbn10"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"isbn13"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"i25"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"codabar"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"code39"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"code93"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"code128"))
		self.crtnaKodaLayout.addWidget(QtGui.QCheckBox(u"qrcode"))
		self.setLayout(self.crtnaKodaLayout)

# ********************************************************************************************
# widget za izbiro programa za prepoznavo besedila
# ********************************************************************************************
class programZaPrepoznavoWidget(QtGui.QWidget):
	def __init__(self):
		super(programZaPrepoznavoWidget, self).__init__()
		prepoznavaHLayout = QtGui.QHBoxLayout()
		prepoznavaWidget = QtGui.QWidget()
		prepoznavaLayout = QtGui.QVBoxLayout()
		prepoznavaWidget.setLayout(prepoznavaLayout)
		prepoznavaStranWidget = QtGui.QGroupBox("Cela stran")
		prepoznavaStranLayout = QtGui.QVBoxLayout()
		prepoznavaStranWidget.setLayout(prepoznavaStranLayout)
		tesseractStranWidget = QtGui.QWidget() # tesseract
		tesseractStranLayout = QtGui.QHBoxLayout()
		tesseractStranWidget.setLayout(tesseractStranLayout)
		self.tesseractCheckBox = QtGui.QCheckBox("Tesseract")
		tesseractStranLayout.addWidget(self.tesseractCheckBox)
		tesseractStranLayout.addStretch(1)
		tesseractStranLayout.addWidget(QtGui.QLabel(u"Jezik:"))
		self.tesseractJezikComboBox = QtGui.QComboBox()
		self.tesseractJezikComboBox.addItems(["slv","bul","cat","ces","dan","deu","ell","eng","fin","fra","hun","ita","lav","lit","nld","nor","pol","por","ron","rus","slk","spa","srp","swe","tur","ukr"])
		tesseractStranLayout.addWidget(self.tesseractJezikComboBox)
		prepoznavaStranLayout.addWidget(tesseractStranWidget)
		cuneiformStranWidget = QtGui.QWidget() # cuneiform
		cuneiformStranLayout = QtGui.QHBoxLayout()
		cuneiformStranWidget.setLayout(cuneiformStranLayout)
		self.cuneiformCheckBox = QtGui.QCheckBox("Cuneiform")
		cuneiformStranLayout.addWidget(self.cuneiformCheckBox)
		cuneiformStranLayout.addStretch(1)
		cuneiformStranLayout.addWidget(QtGui.QLabel(u"Jezik:"))
		self.cuneiformJezikComboBox = QtGui.QComboBox()
		self.cuneiformJezikComboBox.addItems(["slv","bul","cze","dan","dut","est","ger","eng","fra","hun","hrv","ita","lav","lit","pol","por","rum","rus","spa","srp","swe","tur","ukr"])
		cuneiformStranLayout.addWidget(self.cuneiformJezikComboBox)
		prepoznavaStranLayout.addWidget(cuneiformStranWidget)
		prepoznavaLayout.addWidget(prepoznavaStranWidget)
		prepoznavaPoljeWidget = QtGui.QGroupBox("Vnosno polje")
		prepoznavaPoljeLayout = QtGui.QVBoxLayout()
		prepoznavaPoljeWidget.setLayout(prepoznavaPoljeLayout)
		self.prepoznavaPoljeComboBox = QtGui.QComboBox()
		self.prepoznavaPoljeComboBox.addItems(["Brez","Tesseract","Cuneiform"])
		prepoznavaPoljeLayout.addWidget(self.prepoznavaPoljeComboBox)
		poljeDimenzijeWidget = QtGui.QWidget()
		poljeDimenzijeLayout = QtGui.QFormLayout()
		poljeDimenzijeWidget.setLayout(poljeDimenzijeLayout)
		self.xOcrLineEdit = QtGui.QLineEdit()
		self.yOcrLineEdit = QtGui.QLineEdit()
		self.sirinaOcrLineEdit = QtGui.QLineEdit()
		self.visinaOcrLineEdit = QtGui.QLineEdit()
		self.xOcrLineEdit.setValidator(VrednostValidator())
		self.yOcrLineEdit.setValidator(VrednostValidator())
		self.sirinaOcrLineEdit.setValidator(VrednostValidator())
		self.visinaOcrLineEdit.setValidator(VrednostValidator())
		poljeDimenzijeLayout.addRow(QtGui.QLabel(u"x:"),self.xOcrLineEdit)
		poljeDimenzijeLayout.addRow(QtGui.QLabel(u"y:"),self.yOcrLineEdit)
		poljeDimenzijeLayout.addRow(QtGui.QLabel(u"Širina:"),self.sirinaOcrLineEdit)
		poljeDimenzijeLayout.addRow(QtGui.QLabel(u"Višina:"),self.visinaOcrLineEdit)
		prepoznavaPoljeLayout.addWidget(poljeDimenzijeWidget)
		prepoznavaLayout.addWidget(prepoznavaPoljeWidget)
		prepoznavaHLayout.addWidget(prepoznavaWidget)
		prepoznavaHLayout.addStretch(1)
		self.setLayout(prepoznavaHLayout)

# ********************************************************************************************
# widget za izbiro privzete povečave pri tipih dokumentov
# ********************************************************************************************
class privzetaPovecavaWidget(QtGui.QWidget):
	def __init__(self):
		super(privzetaPovecavaWidget, self).__init__()
		povecavaLayout = QtGui.QVBoxLayout()
		self.povecavaButtonGroup = QtGui.QButtonGroup(self)
		najvecjaRadioButton = QtGui.QRadioButton(u"Največja")
		sirinaRadioButton = QtGui.QRadioButton(u"Širina")
		normalnaRadioButton = QtGui.QRadioButton(u"1 : 1")
		visinaRadioButton = QtGui.QRadioButton(u"Višina")
		najmanjsaRadioButton = QtGui.QRadioButton(u"Najmanjša")
		povecavaLayout.addWidget(najvecjaRadioButton)
		povecavaLayout.addWidget(sirinaRadioButton)
		povecavaLayout.addWidget(normalnaRadioButton)
		povecavaLayout.addWidget(visinaRadioButton)
		povecavaLayout.addWidget(najmanjsaRadioButton)
		self.povecavaButtonGroup.addButton(najvecjaRadioButton,1)
		self.povecavaButtonGroup.addButton(sirinaRadioButton,2)
		self.povecavaButtonGroup.addButton(normalnaRadioButton,3)
		self.povecavaButtonGroup.addButton(visinaRadioButton,4)
		self.povecavaButtonGroup.addButton(najmanjsaRadioButton,5)
		normalnaRadioButton.setChecked(True)
		self.setLayout(povecavaLayout)

# ********************************************************************************************
# dialog za Nastavitve -> TipiDokumentov
# ********************************************************************************************
class TipiDokumentovDialog(QtGui.QDialog):
	def __init__(self,parent = None):
		super(TipiDokumentovDialog, self).__init__(parent)
		self.setWindowTitle("Tipi dokumentov")
		layout1 = QtGui.QVBoxLayout()
		tipiDokumentovGlavniWidget = QtGui.QWidget()
		layout1_1 = QtGui.QGridLayout()
		tipiDokumentovGlavniWidget.setLayout(layout1_1)
		self.tipiDokumentovProfiliWidget =  QtGui.QWidget()
		layout1_1_1 = QtGui.QVBoxLayout()
		self.tipiDokumentovProfiliWidget.setLayout(layout1_1_1)
		self.tipiDokumentovIzbiraWidget = QtGui.QWidget()
		self.layout1_1_1_2 = QtGui.QFormLayout()
		self.tipiDokumentovIzbiraWidget.setLayout(self.layout1_1_1_2)
		self.tipDokumentaLineEdit = QtGui.QLineEdit()
		self.layout1_1_1_2.addRow(u"Tip dokumenta:", self.tipDokumentaLineEdit)
		self.tipDokumentaLineEdit.setEnabled(False)
		self.steviloSkenovLabel = QtGui.QLabel("0")
		self.layout1_1_1_2.addRow(u"Število skenov:", self.steviloSkenovLabel)
		self.steviloSkenovLabel.setEnabled(False)
		layout1_1_1.addWidget(self.tipiDokumentovIzbiraWidget)
		self.tipiDokumentovList = QtGui.QListWidget()
		bazaUkaz = baza.cursor()
		tipiDokumentov = bazaUkaz.execute("SELECT tipDokumenta FROM TipiDokumentov").fetchall()
		for tipDokumenta in tipiDokumentov:
			self.tipiDokumentovList.addItem(tipDokumenta[0])
		self.tipiDokumentovList.itemClicked.connect(self.izbranTipDokumenta)
		layout1_1_1.addWidget(self.tipiDokumentovList)
		layout1_1.addWidget(self.tipiDokumentovProfiliWidget,0,0)
		self.tipiDokumentovPodatkiTabWidget = QtGui.QTabWidget()
		self.tipiDokumentovPodatkiTabWidget.addTab(podatkiWidget(),u"Podatki")
		self.tipiDokumentovPodatkiTabWidget.addTab(skeniranjeWidget(),u"Skeniranje")
		self.tipiDokumentovPodatkiTabWidget.addTab(povezovanjeWidget(),u"Povezovanje")
		self.tipiDokumentovPodatkiTabWidget.addTab(izvozWidget(),u"Izvoz")
		self.tipiDokumentovPodatkiTabWidget.addTab(crtnaKodaWidget(),u"Črtna koda")
		self.tipiDokumentovPodatkiTabWidget.addTab(programZaPrepoznavoWidget(),u"Prepoznavanje besedila")
		self.tipiDokumentovPodatkiTabWidget.addTab(privzetaPovecavaWidget(),u"Privzeta povečava")
		self.tipiDokumentovPodatkiTabWidget.setEnabled(False)
		layout1_1.addWidget(self.tipiDokumentovPodatkiTabWidget,0,1)
		layout1_1.setColumnMinimumWidth(0,300)
		layout1_1.setColumnStretch(0,1)
		layout1_1.setColumnMinimumWidth(1,500)
		layout1_1.setColumnStretch(1,2)
		layout1.addWidget(tipiDokumentovGlavniWidget)
		gumbiWidget = QtGui.QWidget()
		layout1_2 = QtGui.QHBoxLayout()
		self.tipiDokumentovNovPushButton = QtGui.QPushButton("Nov tip dokumenta")
		self.tipiDokumentovNovPushButton.clicked.connect(self.novTipDokumenta)
		layout1_2.addWidget(self.tipiDokumentovNovPushButton)
		self.tipiDokumentovShraniPushButton = QtGui.QPushButton("Shrani")
		self.tipiDokumentovShraniPushButton.clicked.connect(self.shraniTipDokumenta)
		self.tipiDokumentovShraniPushButton.setEnabled(False)
		layout1_2.addWidget(self.tipiDokumentovShraniPushButton)
		self.tipiDokumentovPrekliciPushButton = QtGui.QPushButton(u"Prekliči")
		self.tipiDokumentovPrekliciPushButton.clicked.connect(self.prekliciTipDokumenta)
		self.tipiDokumentovPrekliciPushButton.setEnabled(False)
		layout1_2.addWidget(self.tipiDokumentovPrekliciPushButton)
		self.tipiDokumentovZapriPushButton = QtGui.QPushButton("Zapri")
		self.tipiDokumentovZapriPushButton.clicked.connect(self.zapriTipDokumenta)
		layout1_2.addWidget(self.tipiDokumentovZapriPushButton)
		gumbiWidget.setLayout(layout1_2)
		layout1.addWidget(gumbiWidget)
		self.setLayout(layout1)

	# omogoči vnos
	def omogociVnos(self):
		self.tipiDokumentovNovPushButton.setEnabled(False)
		self.tipiDokumentovShraniPushButton.setEnabled(True)
		self.tipiDokumentovPrekliciPushButton.setEnabled(True)
		self.tipiDokumentovPodatkiTabWidget.setEnabled(True)
		self.tipDokumentaLineEdit.setEnabled(True)
		self.tipDokumentaLineEdit.setFocus()

	# onemogoči vnos
	def onemogociVnos(self):
		self.tipiDokumentovNovPushButton.setEnabled(True)
		self.tipiDokumentovShraniPushButton.setEnabled(False)
		self.tipiDokumentovPrekliciPushButton.setEnabled(False)
		self.tipiDokumentovPodatkiTabWidget.setEnabled(False)
		self.tipDokumentaLineEdit.setText("")
		self.tipDokumentaLineEdit.setEnabled(False)

	# uporabnik je v listi tipov dokumentov izbral en tip dokumenta
	def izbranTipDokumenta(self,tipDokumenta):
		izbranTipDokumenta = tipDokumenta.text()
		self.tipDokumentaLineEdit.setText(izbranTipDokumenta)
		bazaUkaz = baza.cursor()
		tipDokumentaOpcije = bazaUkaz.execute(
		'''
			SELECT steviloSkenov,skener,profil,povezovanje,povezovanjeModul,izvoz,izvozmodul,crtnaKoda,tesseract,tesseractJezik,cuneiform,cuneiformJezik,poljeOcr,xOcr,yOcr,sirinaOcr,visinaOcr,povecava
			FROM TipiDokumentov
			WHERE tipDokumenta = ?
		''',[izbranTipDokumenta]).fetchone()
		steviloSkenov = tipDokumentaOpcije[0]
		self.steviloSkenovLabel.setText(str(steviloSkenov))
		skener = tipDokumentaOpcije[1]
		skenerWidget = self.tipiDokumentovPodatkiTabWidget.widget(1).skenerComboBox
		skenerWidget.setCurrentIndex(skenerWidget.findText(skener))
		profil = tipDokumentaOpcije[2]
		profilWidget = self.tipiDokumentovPodatkiTabWidget.widget(1).profilComboBox
		profilWidget.setCurrentIndex(profilWidget.findText(profil))
		povezovanje = tipDokumentaOpcije[3]
		self.tipiDokumentovPodatkiTabWidget.widget(2).povezovanjeButtonGroup.button(povezovanje).setChecked(True)
		povezovanjeModul = tipDokumentaOpcije[4]
		povezovanjeModulWidget = self.tipiDokumentovPodatkiTabWidget.widget(2)
		povezovanjeModulWidget.povezovanjeComboBox.setCurrentIndex(povezovanjeModulWidget.povezovanjeComboBox.findText(povezovanjeModul))
		izvoz = tipDokumentaOpcije[5]
		self.tipiDokumentovPodatkiTabWidget.widget(3).izvozButtonGroup.button(izvoz).setChecked(True)
		izvozModul = tipDokumentaOpcije[6]
		izvozModulWidget = self.tipiDokumentovPodatkiTabWidget.widget(3)
		izvozModulWidget.izvoziComboBox.setCurrentIndex(izvozModulWidget.izvoziComboBox.findText(izvozModul))
		crtnaKodaList = eval(tipDokumentaOpcije[7])
		crtnaKoda = self.tipiDokumentovPodatkiTabWidget.widget(4).crtnaKodaLayout
		for i in range(0,crtnaKoda.count()):
			crtnaKoda.itemAt(i).widget().setChecked(crtnaKodaList.pop(0))
		tesseract = tipDokumentaOpcije[8]
		self.tipiDokumentovPodatkiTabWidget.widget(5).tesseractCheckBox.setChecked(tesseract)
		tesseractJezik = tipDokumentaOpcije[9]
		tesseractJezikWidget = self.tipiDokumentovPodatkiTabWidget.widget(5).tesseractJezikComboBox
		tesseractJezikWidget.setCurrentIndex(tesseractJezikWidget.findText(tesseractJezik))
		cuneiform = tipDokumentaOpcije[10]
		self.tipiDokumentovPodatkiTabWidget.widget(5).cuneiformCheckBox.setChecked(cuneiform)
		cuneiformJezik = tipDokumentaOpcije[11]
		cuneiformJezikWidget = self.tipiDokumentovPodatkiTabWidget.widget(5).cuneiformJezikComboBox
		cuneiformJezikWidget.setCurrentIndex(cuneiformJezikWidget.findText(cuneiformJezik))
		poljeOcr = tipDokumentaOpcije[12]
		poljeOcrWidget = self.tipiDokumentovPodatkiTabWidget.widget(5).prepoznavaPoljeComboBox
		poljeOcrWidget.setCurrentIndex(poljeOcrWidget.findText(poljeOcr))
		xOcr = tipDokumentaOpcije[13]
		self.tipiDokumentovPodatkiTabWidget.widget(5).xOcrLineEdit.setText(xOcr)
		yOcr = tipDokumentaOpcije[14]
		self.tipiDokumentovPodatkiTabWidget.widget(5).yOcrLineEdit.setText(yOcr)
		sirinaOcr = tipDokumentaOpcije[15]
		self.tipiDokumentovPodatkiTabWidget.widget(5).sirinaOcrLineEdit.setText(sirinaOcr)
		visinaOcr = tipDokumentaOpcije[16]
		self.tipiDokumentovPodatkiTabWidget.widget(5).visinaOcrLineEdit.setText(visinaOcr)
		povecava = tipDokumentaOpcije[17]
		self.tipiDokumentovPodatkiTabWidget.widget(6).povecavaButtonGroup.button(povecava).setChecked(True)
		tabela = self.tipiDokumentovPodatkiTabWidget.widget(0).tabelaWidget
		tabela.clear()
		tabela.setHorizontalHeaderLabels([u"Ime",u"Tip"])
		tabela.setRowCount(1)
		vnosnaPoljaList = bazaUkaz.execute(
		'''
			SELECT naziv,tip
			FROM VnosnaPolja,TipiDokumentov
			WHERE tipDokumenta = ? AND TipiDokumentov.rowid = idTipDokumenta
			ORDER BY zaporedna
		''',[izbranTipDokumenta]).fetchall()
		for polje in vnosnaPoljaList:
			vrstica = tabela.rowCount() - 1
			tabela.setItem(vrstica,0,QtGui.QTableWidgetItem(polje[0]))
			tabela.setItem(vrstica,1,QtGui.QTableWidgetItem(polje[1]))
			tabela.setRowCount(tabela.rowCount() + 1)
			tabela.scrollToBottom()
		self.omogociVnos()

	# gumb Nov - pripravi vse za vnos novega tipa dokumenta
	def novTipDokumenta(self):
		self.omogociVnos()

	# gumb Shrani - shrani tip dokumenta v podatkovno bazo
	def shraniTipDokumenta(self):
		tipDokumenta = self.tipDokumentaLineEdit.text()
		steviloSkenov = self.steviloSkenovLabel.text()
		if tipDokumenta:
			skener = self.tipiDokumentovPodatkiTabWidget.widget(1).skenerComboBox.currentText()
			profil = self.tipiDokumentovPodatkiTabWidget.widget(1).profilComboBox.currentText()
			povezovanje = self.tipiDokumentovPodatkiTabWidget.widget(2).povezovanjeButtonGroup.checkedId()
			povezovanjeModul = self.tipiDokumentovPodatkiTabWidget.widget(2).povezovanjeComboBox.currentText()
			izvoz = self.tipiDokumentovPodatkiTabWidget.widget(3).izvozButtonGroup.checkedId()
			izvozModul = self.tipiDokumentovPodatkiTabWidget.widget(3).izvoziComboBox.currentText()
			crtnaKoda = self.tipiDokumentovPodatkiTabWidget.widget(4).crtnaKodaLayout
			crtnaKodaList = []
			for i in range(0,crtnaKoda.count()):
				crtnaKodaList.append(crtnaKoda.itemAt(i).widget().isChecked())
			tesseract = self.tipiDokumentovPodatkiTabWidget.widget(5).tesseractCheckBox.isChecked()
			tesseractJezik = self.tipiDokumentovPodatkiTabWidget.widget(5).tesseractJezikComboBox.currentText()
			cuneiform = self.tipiDokumentovPodatkiTabWidget.widget(5).cuneiformCheckBox.isChecked()
			cuneiformJezik = self.tipiDokumentovPodatkiTabWidget.widget(5).cuneiformJezikComboBox.currentText()
			poljeOcr = self.tipiDokumentovPodatkiTabWidget.widget(5).prepoznavaPoljeComboBox.currentText()
			xOcr = self.tipiDokumentovPodatkiTabWidget.widget(5).xOcrLineEdit.text()
			yOcr = self.tipiDokumentovPodatkiTabWidget.widget(5).yOcrLineEdit.text()
			sirinaOcr = self.tipiDokumentovPodatkiTabWidget.widget(5).sirinaOcrLineEdit.text()
			visinaOcr = self.tipiDokumentovPodatkiTabWidget.widget(5).visinaOcrLineEdit.text()
			povecava = self.tipiDokumentovPodatkiTabWidget.widget(6).povecavaButtonGroup.checkedId()
			bazaUkaz = baza.cursor()
			idTipDokumenta = bazaUkaz.execute(
			'''
				INSERT OR REPLACE INTO TipiDokumentov
					(tipDokumenta,steviloSkenov,skener,profil,povezovanje,povezovanjemodul,izvoz,izvozModul,crtnaKoda,tesseract,tesseractJezik,cuneiform,cuneiformJezik,poljeOcr,xOcr,yOcr,sirinaOcr,visinaOcr,povecava)
				VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)
			''',[tipDokumenta,steviloSkenov,skener,profil,povezovanje,povezovanjeModul,izvoz,izvozModul,repr(crtnaKodaList),tesseract,tesseractJezik,cuneiform,cuneiformJezik,poljeOcr,xOcr,yOcr,sirinaOcr,visinaOcr,povecava]).lastrowid
			bazaUkaz.execute("DELETE FROM VnosnaPolja WHERE idTipDokumenta = ?",[idTipDokumenta]) # zapisemo vnosna polja
			tabela = self.tipiDokumentovPodatkiTabWidget.widget(0).tabelaWidget
			for i in range(0,tabela.rowCount()-1):
				bazaUkaz.execute(
				'''
					INSERT INTO VnosnaPolja
						(idTipDokumenta,naziv,tip,zaporedna)
					VALUES (?,?,?,?)
				''',[idTipDokumenta,tabela.item(i,0).text(),tabela.item(i,1).text(),i])
			baza.commit()
			self.tipiDokumentovList.clearSelection()
			self.onemogociVnos()
			if not self.tipiDokumentovList.findItems(tipDokumenta,QtCore.Qt.MatchExactly):
				self.tipiDokumentovList.addItem(tipDokumenta)
		else:
			napakaDialog = NapakaDialog(self,"Tip dokumenta mora biti vpisan!")
			napakaDialog.exec_()

	# gumb Prekliči - prekliče spremembe, ki jih je uporabnik naredil za trenutni tip dokumenta
	def prekliciTipDokumenta(self):
		self.tipiDokumentovList.clearSelection()
		self.onemogociVnos()

	# gumb Zapri - zapre dialog
	def zapriTipDokumenta(self):
		self.close()

# ********************************************************************************************
# dialog za Nastavitve -> Skenerji
# ********************************************************************************************
class SkenerjiDialog(QtGui.QDialog):
	def __init__(self,parent = None):
		super(SkenerjiDialog, self).__init__(parent)
		self.setWindowTitle("Skenerji")
		layout1 = QtGui.QVBoxLayout()
		skenerjiGlavniWidget = QtGui.QWidget()
		layout1_1 = QtGui.QGridLayout()
		skenerjiGlavniWidget.setLayout(layout1_1)
		skenerProfiliWidget =  QtGui.QWidget()
		layout1_1_1 = QtGui.QVBoxLayout()
		skenerProfiliWidget.setLayout(layout1_1_1)
		self.skenerIzbiraWidget = QtGui.QWidget()
		layout1_1_1_2 = QtGui.QFormLayout()
		self.skenerIzbiraWidget.setLayout(layout1_1_1_2)
		self.skenerIzbiraComboBox = QtGui.QComboBox()
		self.skenerIzbiraComboBox.addItem(glavnoOkno.skenerName)
		layout1_1_1_2.addRow("Skener:", self.skenerIzbiraComboBox)
		self.profilLineEdit = QtGui.QLineEdit()
		layout1_1_1_2.addRow("Profil:", self.profilLineEdit)
		self.profilLineEdit.setEnabled(False)
		layout1_1_1.addWidget(self.skenerIzbiraWidget)
		self.profiliList = QtGui.QListWidget()
		self.profiliList.itemClicked.connect(self.izbranProfil)
		layout1_1_1.addWidget(self.profiliList)
		layout1_1.addWidget(skenerProfiliWidget,0,0)
		self.profiliPodatkiTabWidget = QtGui.QTabWidget()
		tmpOpcije = copy.deepcopy(glavnoOkno.scanimageOpcije)
		for sekcija in tmpOpcije: # iz liste scanimageOpcije dobimo vse možnosti in jih pokažemo kot TabWidget
			sekcijaText = sekcija.pop(0)[0]
			vsebinaWidget = QtGui.QWidget()
			vsebinaLayout = QtGui.QFormLayout()
			vsebinaWidget.setLayout(vsebinaLayout)
			for opcija in sekcija:
				opcijaText = opcija.pop(0)
				opcijaLineEdit = QtGui.QLineEdit()
				opcijaLineEdit.setText(opcija.pop(0))
				helpText = u""
				for tmpHelp in opcija:
					helpText += tmpHelp + "\n"
				opcijaLineEdit.setToolTip(helpText)
				vsebinaLayout.addRow(opcijaText,opcijaLineEdit)
			self.profiliPodatkiTabWidget.addTab(vsebinaWidget,sekcijaText)
		self.profiliPodatkiTabWidget.setEnabled(False)
		layout1_1.addWidget(self.profiliPodatkiTabWidget,0,1)
		layout1_1.setColumnMinimumWidth(0,200)
		layout1_1.setColumnStretch(0,1)
		layout1_1.setColumnMinimumWidth(1,400)
		layout1_1.setColumnStretch(1,2)
		layout1.addWidget(skenerjiGlavniWidget)
		gumbiWidget = QtGui.QWidget()
		layout1_2 = QtGui.QHBoxLayout()
		self.skenerjiNovPushButton = QtGui.QPushButton("Nov profil")
		self.skenerjiNovPushButton.clicked.connect(self.novSkenerProfil)
		layout1_2.addWidget(self.skenerjiNovPushButton)
		self.skenerjiShraniPushButton = QtGui.QPushButton("Shrani")
		self.skenerjiShraniPushButton.clicked.connect(self.shraniSkenerProfil)
		self.skenerjiShraniPushButton.setEnabled(False)
		layout1_2.addWidget(self.skenerjiShraniPushButton)
		self.skenerjiPrekliciPushButton = QtGui.QPushButton(u"Prekliči")
		self.skenerjiPrekliciPushButton.clicked.connect(self.prekliciSpremembe)
		self.skenerjiPrekliciPushButton.setEnabled(False)
		layout1_2.addWidget(self.skenerjiPrekliciPushButton)
		self.skenerjiZapriPushButton = QtGui.QPushButton("Zapri")
		self.skenerjiZapriPushButton.clicked.connect(self.zapriDialog)
		layout1_2.addWidget(self.skenerjiZapriPushButton)
		gumbiWidget.setLayout(layout1_2)
		layout1.addWidget(gumbiWidget)
		self.setLayout(layout1)
		self.poisciProfile()

	# v bazi poiščemo vse profile za priključen skener in jih dodamo v listo
	def poisciProfile(self):
		skener =  self.skenerIzbiraComboBox.currentText()
		bazaUkaz = baza.cursor()
		profiliList = bazaUkaz.execute(
		'''
			SELECT profil 
			FROM skenerji,profili
			WHERE Profili.skenerId = Skenerji.rowid AND  skener = ?
		''',[skener]).fetchall()
		for profil in profiliList:
			self.profiliList.addItem(profil[0])

	# omogoči vnos
	def omogociVnos(self):
		self.skenerjiNovPushButton.setEnabled(False)
		self.skenerjiShraniPushButton.setEnabled(True)
		self.skenerjiPrekliciPushButton.setEnabled(True)
		self.profiliPodatkiTabWidget.setEnabled(True)
		self.profilLineEdit.setEnabled(True)
		self.profilLineEdit.setFocus()

	# onemogoči vnos
	def onemogociVnos(self):
		self.skenerjiNovPushButton.setEnabled(True)
		self.skenerjiShraniPushButton.setEnabled(False)
		self.skenerjiPrekliciPushButton.setEnabled(False)
		self.profiliPodatkiTabWidget.setEnabled(False)
		self.profilLineEdit.setText("")
		self.profilLineEdit.setEnabled(False)

	# uporabnik je v listi profilov izbral en profil
	def izbranProfil(self,profil):
		izbranProfil = profil.text()
		self.profilLineEdit.setText(izbranProfil)
		izbranSkener = self.skenerIzbiraComboBox.currentText()
		bazaUkaz = baza.cursor()
		for i in range(0,self.profiliPodatkiTabWidget.count()):
			tmpWidgetLayout = self.profiliPodatkiTabWidget.widget(i).layout()
			for j in range(0,tmpWidgetLayout.rowCount()):
				nastavitev = bazaUkaz.execute(
				'''
					SELECT vrednost 
					FROM Skenerji,Profili,Nastavitve
					WHERE skener = ?
					AND profil = ?
					AND Profili.SkenerId = Skenerji.rowid
					AND Nastavitve.profilId = Profili.id
					AND Nastavitve.sekcija = ?
					AND Nastavitve.zaporedna = ?
				''',[izbranSkener,izbranProfil,i,j]).fetchone()
				tmpWidgetLayout.itemAt(j,QtGui.QFormLayout.FieldRole).widget().setText(nastavitev[0])
		self.profiliList.clearSelection()
		self.omogociVnos()

	# gumb Nov profil - pripravi vse za vnos novega profila
	def novSkenerProfil(self):
		self.omogociVnos()

	# gumb Shrani - shrani trenutni profil skeniranja
	def shraniSkenerProfil(self):
		skener = self.skenerIzbiraComboBox.currentText()
		bazaUkaz = baza.cursor()
		skenerId = bazaUkaz.execute(
		'''
			SELECT rowid 
			FROM Skenerji 
			WHERE skener = ?
		''',[skener]).fetchone()
		if not skenerId:
			skenerId = (bazaUkaz.execute("INSERT INTO Skenerji (skener) VALUES (?)",[skener]).lastrowid,)
			baza.commit()
		profil = self.profilLineEdit.text()
		if profil: # ali obstaja profil?
			bazaUkaz = baza.cursor()
			profilId = bazaUkaz.execute("SELECT id FROM Profili WHERE profil = ?",[profil]).fetchone()
			if not profilId: # profil ne obstaja - dodamo ga v bazo in spisek profilov
				profilId = (bazaUkaz.execute("INSERT INTO Profili (skenerId,profil) VALUES (?,?)",[skenerId[0],profil]).lastrowid,)
				baza.commit()
				self.profiliList.addItem(profil)
			bazaUkaz = baza.cursor()
			for i in range(0,self.profiliPodatkiTabWidget.count()):
				tmpWidgetLayout = self.profiliPodatkiTabWidget.widget(i).layout()
				for j in range(0,tmpWidgetLayout.rowCount()):
					nastavitev = tmpWidgetLayout.itemAt(j,QtGui.QFormLayout.LabelRole).widget().text()
					vrednost = tmpWidgetLayout.itemAt(j,QtGui.QFormLayout.FieldRole).widget().text()
					bazaUkaz.execute(
					'''
						INSERT OR REPLACE INTO Nastavitve 
							(profilId,nastavitev,vrednost,sekcija,zaporedna) 
						VALUES (?,?,?,?,?)
					''',[profilId[0],nastavitev,vrednost,i,j])
				baza.commit()
			self.profilLineEdit.setText("")
			self.onemogociVnos()
		else: # če ne obstaja je napaka
			napakaDialog = NapakaDialog(self,"Ime profila mora biti vpisano!")
			napakaDialog.exec_()

	# gumb Prekliči - prekliče vse spremembe
	def prekliciSpremembe(self):
		self.onemogociVnos()

	# gumb Zapri - zapre Skenerji dialog
	def zapriDialog(self):
		self.close()

# ********************************************************************************************
# dialog za prijavo v program
# ********************************************************************************************
class PrijavaDialog(QtGui.QDialog):
	def __init__(self,parent = None):
		super(PrijavaDialog, self).__init__(parent)
		self.prijavaOk = False
		self.setWindowTitle("Zajem -> Prijava")
		layout1 = QtGui.QVBoxLayout()
		prijavaWidget = QtGui.QWidget()
		self.layout1_1 = QtGui.QFormLayout()
		prijavaWidget.setLayout(self.layout1_1)
		self.prijavaUporabnikLineEdit = QtGui.QLineEdit()
		self.layout1_1.addRow("Uporabnik:", self.prijavaUporabnikLineEdit)
		self.prijavaGesloLineEdit = QtGui.QLineEdit()
		self.prijavaGesloLineEdit.setEchoMode(QtGui.QLineEdit.Password)
		self.layout1_1.addRow("Geslo:", self.prijavaGesloLineEdit)
		layout1.addWidget(prijavaWidget)
		gumbiWidget = QtGui.QWidget()
		layout1_2 = QtGui.QHBoxLayout()
		gumbiWidget.setLayout(layout1_2)
		prijavaPrekliciPushButton = QtGui.QPushButton(u"Prekliči",self)
		prijavaPrekliciPushButton.clicked.connect(self.prekliciPrijava)
		layout1_2.addWidget(prijavaPrekliciPushButton)
		prijavaPotrdiPushButton = QtGui.QPushButton(u"Potrdi",self)
		prijavaPotrdiPushButton.setDefault(True)
		prijavaPotrdiPushButton.clicked.connect(self.potrdiPrijava)
		layout1_2.addWidget(prijavaPotrdiPushButton)
		layout1.addWidget(gumbiWidget)
		self.setLayout(layout1)

	# uporabnik je zaprl dialog s tipko Esc
	def reject(self):
		sys.exit()

	# uporabnik je zaprl dialog s klikom na x
	def closeEvent(self,event):
		if not self.prijavaOk:
			sys.exit()

	# gumb Prekliči - uporabnik je preklical prijavo
	def prekliciPrijava(self):
		sys.exit()
		
	# gumb Potrdi - uporabnik je potrdil uporabniško ime in geslo
	def potrdiPrijava(self):
		global uporabnik
		global aktiven
		global administrator
		global skenira
		tmpUporabnik = self.prijavaUporabnikLineEdit.text()
		geslo = self.prijavaGesloLineEdit.text()
		bazaUkaz = baza.cursor()
		rezultat = bazaUkaz.execute(
		'''
			SELECT geslo,aktiven,administrator,skenira
			FROM Uporabniki
			WHERE uporabnik = ?
		''',(tmpUporabnik,)).fetchone()
		if rezultat:
			digest = crypt.crypt(geslo,rezultat[0])
			if digest == rezultat[0]:
				uporabnik = tmpUporabnik
				aktiven = rezultat[1]
				if aktiven:
					administrator = rezultat[2]
					skenira =  rezultat[3]
					self.prijavaOk = True
					self.close()
				else:
					napakaDialog = NapakaDialog(self,tmpUporabnik + " ni aktiven uporabnik!")
					napakaDialog.exec_()
			else:
				napakaDialog = NapakaDialog(self,"Geslo za uporabnika " + tmpUporabnik + " ni pravilno!")
				napakaDialog.exec_()
		else:
			napakaDialog = NapakaDialog(self,"Uporabnik " + tmpUporabnik + " ne obstaja!")
			napakaDialog.exec_()

# ********************************************************************************************
# dialog za spremembo gesla trenutnega uporabnika
# ********************************************************************************************
class SpremeniGesloDialog(QtGui.QDialog):
	def __init__(self,parent = None):
		super(SpremeniGesloDialog, self).__init__(parent)
		self.setWindowTitle("Sprememba gesla")
		layout1 = QtGui.QVBoxLayout()
		prijavaWidget = QtGui.QWidget()
		self.layout1_1 = QtGui.QFormLayout()
		prijavaWidget.setLayout(self.layout1_1)
		self.prijavaGeslo1LineEdit = QtGui.QLineEdit()
		self.prijavaGeslo1LineEdit.setEchoMode(QtGui.QLineEdit.Password)
		self.layout1_1.addRow("Geslo:", self.prijavaGeslo1LineEdit)
		self.prijavaGeslo2LineEdit = QtGui.QLineEdit()
		self.prijavaGeslo2LineEdit.setEchoMode(QtGui.QLineEdit.Password)
		self.layout1_1.addRow("Geslo:", self.prijavaGeslo2LineEdit)
		layout1.addWidget(prijavaWidget)
		gumbiWidget = QtGui.QWidget()
		layout1_2 = QtGui.QHBoxLayout()
		gumbiWidget.setLayout(layout1_2)
		prijavaPrekliciPushButton = QtGui.QPushButton(u"Prekliči",self)
		prijavaPrekliciPushButton.clicked.connect(self.prekliciPrijava)
		layout1_2.addWidget(prijavaPrekliciPushButton)
		prijavaPotrdiPushButton = QtGui.QPushButton(u"Potrdi",self)
		prijavaPotrdiPushButton.setDefault(True)
		prijavaPotrdiPushButton.clicked.connect(self.potrdiPrijava)
		layout1_2.addWidget(prijavaPotrdiPushButton)
		layout1.addWidget(gumbiWidget)
		self.setLayout(layout1)

	# gumb Prekliči - uporabnik je preklical prijavo
	def prekliciPrijava(self):
		self.close()
		
	# gumb Potrdi - uporabnik je potrdil uporabniško ime in geslo
	def potrdiPrijava(self):
		global uporabnik
		geslo1 = self.prijavaGeslo1LineEdit.text()
		geslo2 = self.prijavaGeslo2LineEdit.text()
		if geslo1 == geslo2 and geslo1 != "": # preverimo če sta gesli enaki in nista prazni
			salt = crypt.mksalt(crypt.METHOD_SHA256)
			digest = crypt.crypt(geslo1,salt) # v bazo ne shranimo gesla ampak soljen hash
			bazaUkaz = baza.cursor()
			bazaUkaz.execute(
			'''
				UPDATE Uporabniki
				SET geslo = ?
				WHERE uporabnik = ?
			''',[digest,uporabnik])
			baza.commit()
			self.close()
		else: # napaka - gesli sta prazni ali nista enaki
			napakaDialog = NapakaDialog(self,"Gesli sta prazni ali nista enaki!")
			napakaDialog.exec_()
			self.prijavaGeslo1LineEdit.setText("")
			self.prijavaGeslo2LineEdit.setText("")
			self.prijavaGeslo1LineEdit.setFocus()

# ********************************************************************************************
# dialog za Nastavitve -> Uporabniki
# ********************************************************************************************
class UporabnikiDialog(QtGui.QDialog):
	def __init__(self,parent = None):
		super(UporabnikiDialog, self).__init__(parent)
		self.setWindowTitle("Uporabniki")
		layout1 = QtGui.QVBoxLayout()
		uporabnikiGlavniWidget = QtGui.QWidget()
		layout1_1 = QtGui.QHBoxLayout()
		self.uporabnikiList = QtGui.QListWidget()
		self.uporabnikiList.itemClicked.connect(self.izbranUporabnik)
		layout1_1.addWidget(self.uporabnikiList)
		uporabnikPodatkiWidget = QtGui.QWidget()
		self.layout1_1_2 = QtGui.QFormLayout()
		uporabnikPodatkiWidget.setLayout(self.layout1_1_2)
		self.layout1_1_2.addRow("Uporabnik:", QtGui.QLineEdit())
		self.layout1_1_2.addRow("Ime:", QtGui.QLineEdit())
		self.layout1_1_2.addRow("Priimek:", QtGui.QLineEdit())
		self.uporabnikGeslo1LineEdit = QtGui.QLineEdit()
		self.uporabnikGeslo1LineEdit.setEchoMode(QtGui.QLineEdit.Password)
		self.layout1_1_2.addRow("Geslo:", self.uporabnikGeslo1LineEdit)
		self.uporabnikGeslo2LineEdit = QtGui.QLineEdit()
		self.uporabnikGeslo2LineEdit.setEchoMode(QtGui.QLineEdit.Password)
		self.layout1_1_2.addRow("Geslo:", self.uporabnikGeslo2LineEdit)
		layout1_1.addWidget(uporabnikPodatkiWidget)
		self.uporabnikiStatusi = QtGui.QWidget()
		self.layout1_1_3 = QtGui.QVBoxLayout()
		self.uporabnikiStatusi.setLayout(self.layout1_1_3)
		self.layout1_1_3.addWidget(QtGui.QCheckBox("Aktiven"))
		self.layout1_1_3.addWidget(QtGui.QCheckBox("Skenira"))
		self.layout1_1_3.addWidget(QtGui.QCheckBox("Administrator"))
		layout1_1.addWidget(self.uporabnikiStatusi)
		uporabnikiGlavniWidget.setLayout(layout1_1)
		layout1.addWidget(uporabnikiGlavniWidget)
		gumbiWidget = QtGui.QWidget()
		layout1_2 = QtGui.QHBoxLayout()
		gumbiWidget.setLayout(layout1_2)
		self.uporabnikNovPushButton = QtGui.QPushButton("Nov")
		self.uporabnikNovPushButton.clicked.connect(self.novUporabnik)
		layout1_2.addWidget(self.uporabnikNovPushButton)
		self.uporabnikShraniPushButton = QtGui.QPushButton("Shrani")
		self.uporabnikShraniPushButton.clicked.connect(self.shraniUporabnika)
		layout1_2.addWidget(self.uporabnikShraniPushButton)
		self.uporabnikPrekliciPushButton = QtGui.QPushButton(u"Prekliči")
		self.uporabnikPrekliciPushButton.clicked.connect(self.prekliciSpremembe)
		layout1_2.addWidget(self.uporabnikPrekliciPushButton)
		self.uporabnikZapriPushButton = QtGui.QPushButton("Zapri")
		self.uporabnikZapriPushButton.clicked.connect(self.zapriDialog)
		layout1_2.addWidget(self.uporabnikZapriPushButton)
		layout1.addWidget(gumbiWidget)
		self.setLayout(layout1)
		self.onemogociVnos()
		self.podatkiIzBaze()

	# omogoči vnosna polja
	def omogociVnos(self):
		for i in range(0,self.layout1_1_2.rowCount()):
			self.layout1_1_2.itemAt(i,QtGui.QFormLayout.LabelRole).widget().setEnabled(True)
			self.layout1_1_2.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setEnabled(True)
		for i in range(0,self.layout1_1_3.count()):
			self.layout1_1_3.itemAt(i).widget().setEnabled(True)
		self.uporabnikNovPushButton.setEnabled(False)
		self.uporabnikShraniPushButton.setEnabled(True)
		self.uporabnikPrekliciPushButton.setEnabled(True)

	# onemogoči vnosna polja
	def onemogociVnos(self):
		for i in range(0,self.layout1_1_2.rowCount()):
			self.layout1_1_2.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")
			self.layout1_1_2.itemAt(i,QtGui.QFormLayout.LabelRole).widget().setDisabled(True)
			self.layout1_1_2.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setDisabled(True)
		for i in range(0,self.layout1_1_3.count()):
			self.layout1_1_3.itemAt(i).widget().setCheckState(QtCore.Qt.Unchecked)
			self.layout1_1_3.itemAt(i).widget().setDisabled(True)
		self.uporabnikNovPushButton.setEnabled(True)
		self.uporabnikShraniPushButton.setEnabled(False)
		self.uporabnikPrekliciPushButton.setEnabled(False)

	# počisti vsa vnosna polja
	def pocistiVnosnaPolja(self):
		for i in range(0,self.layout1_1_2.rowCount()):
			self.layout1_1_2.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")
		for i in range(0,self.layout1_1_3.count()):
			self.layout1_1_3.itemAt(i).widget().setCheckState(QtCore.Qt.Unchecked)

	# iz baze prečita obstoječe uporabnike in jih doda na seznam
	def podatkiIzBaze(self):
		bazaUkaz = baza.cursor()
		rezultat = bazaUkaz.execute("SELECT uporabnik FROM Uporabniki")
		for uporabnik in rezultat:
			self.uporabnikiList.addItem(uporabnik[0])

	# uporabnik je v listi uporabnikov izbral enega izmed uporabnikov
	def izbranUporabnik(self,uporabnik):
		izbranUporabnik = uporabnik.text()
		bazaUkaz = baza.cursor()
		rezultat = bazaUkaz.execute(
			'''
				SELECT uporabnik,ime,priimek,aktiven,skenira,administrator
				FROM Uporabniki
				WHERE uporabnik = ?
			''',(izbranUporabnik,)).fetchone()
		for i in range(0,3):
			self.layout1_1_2.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText(rezultat[i])
		self.layout1_1_2.itemAt(3,QtGui.QFormLayout.FieldRole).widget().setText("*****")
		self.layout1_1_2.itemAt(4,QtGui.QFormLayout.FieldRole).widget().setText("*****") 
		for i in range(0,3):
			self.layout1_1_3.itemAt(i).widget().setChecked(rezultat[i+3])
		self.omogociVnos()
		self.layout1_1_2.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setDisabled(True)

	# gumb Nov - pripravi vse za vpis novega uporabnika
	def novUporabnik(self):
		self.uporabnikiList.clearSelection()
		self.pocistiVnosnaPolja()
		self.omogociVnos()
		self.layout1_1_2.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setFocus()
		self.layout1_1_3.itemAt(0).widget().setCheckState(QtCore.Qt.Checked)

	# gumb Shrani - shrani uporabnika v bazo in onemogoči vnosna polja
	def shraniUporabnika(self):
		podatki = []
		for i in range(0,self.layout1_1_2.rowCount()):
			podatki.append(self.layout1_1_2.itemAt(i,QtGui.QFormLayout.FieldRole).widget().text())
		if podatki[0]:
			if podatki[3] == podatki[4] and podatki[3] != "": # preverimo če sta gesli enaki in nista prazni
				podatki.pop()
				if self.layout1_1_2.itemAt(0,QtGui.QFormLayout.FieldRole).widget().isEnabled() or podatki[3] != "*****":
					salt = crypt.mksalt(crypt.METHOD_SHA256)
					digest = crypt.crypt(podatki.pop(),salt) # v bazo ne shranimo gesla ampak soljen hash
					podatki.append(digest)
					for i in range(0,self.layout1_1_3.count()):
						podatki.append(self.layout1_1_3.itemAt(i).widget().isChecked())
					bazaUkaz = baza.cursor()
					bazaUkaz.execute(
						'''
							INSERT OR REPLACE INTO Uporabniki
								(uporabnik,ime,priimek,geslo,aktiven,skenira,administrator)
							VALUES (?,?,?,?,?,?,?)
						''',podatki)
					baza.commit()
					if self.layout1_1_2.itemAt(0,QtGui.QFormLayout.FieldRole).widget().isEnabled():
						self.uporabnikiList.addItem(self.layout1_1_2.itemAt(0,QtGui.QFormLayout.FieldRole).widget().text())
				else: # če uporabnika spreminjamo in nismo spremenili gesla ga shranimo brez spremembe gesla
					podatki.pop();
					for i in range(0,self.layout1_1_3.count()):
						podatki.append(self.layout1_1_3.itemAt(i).widget().isChecked())
					podatki.append(podatki.pop(0))
					bazaUkaz = baza.cursor()
					bazaUkaz.execute(
						'''
							UPDATE Uporabniki
								set ime = ?, priimek = ?,aktiven = ?,skenira = ?,administrator = ?
							WHERE uporabnik = ?
						''',podatki)
					baza.commit()
				self.onemogociVnos()
				self.uporabnikiList.clearSelection()
			else: # napaka - gesli sta prazni ali nista enaki
				napakaDialog = NapakaDialog(self,"Gesli sta prazni ali nista enaki!")
				napakaDialog.exec_()
				self.layout1_1_2.itemAt(3,QtGui.QFormLayout.FieldRole).widget().setText("")
				self.layout1_1_2.itemAt(4,QtGui.QFormLayout.FieldRole).widget().setText("")
				self.layout1_1_2.itemAt(3,QtGui.QFormLayout.FieldRole).widget().setFocus()
		else: # napaka - ni vpisano uporabniško ime
			napakaDialog = NapakaDialog(self,"Uporabnik mora biti vpisan!")
			napakaDialog.exec_()
			self.layout1_1_2.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setFocus()

	# gumb Prekliči - prekliče vse spremembe
	def prekliciSpremembe(self):
		self.uporabnikiList.clearSelection()
		self.pocistiVnosnaPolja()
		self.onemogociVnos()

	# gumb Zapri - zapre Uporabniki dialog
	def zapriDialog(self):
		self.close()

# ********************************************************************************************
# glavno okno programa
# ********************************************************************************************
class GlavnoOkno(QtGui.QMainWindow):
	def __init__(self):
		super(GlavnoOkno, self).__init__()
		self.preveriDirektorije()
		self.poveziBazo()
		self.poisciExportModule()
		self.poisciDatabaseModule()
		self.skenerName = None
		self.skener = None
		self.profil = None
		self.tipDokumenta = None
		self.skenString = None
		self.skenirajEnListThread = None
		self.skenirajVseListeThread = None
		self.uporabnik = ""
		self.resize(QtCore.QSize(1000,720))
		self.setWindowTitle("Zajem v.0.1 alfa")
		prijavaDialog = PrijavaDialog(self)
		prijavaDialog.exec_()
		self.initMeni()
		if skenira:
			self.initOrodnaVrsticaTipi(True)
		self.initOrodnaVrsticaAkcije()
		self.initStatusnaVrstica()
		self.initThumbnails()
		self.initPodatkiDokumenta()
		self.initPogledDokumenta()
		self.initGlavniDel()
		if skenira:
			self.addToolBar(self.orodnaVrsticaTipiToolBar)
		self.poisciSkenerThread = PoisciSkenerThread()
		self.poisciSkenerThread.started.connect(self.isciSkenerStart)
		self.poisciSkenerThread.finished.connect(self.isciSkenerFinish)
		self.poisciSkenerThread.start()
		
	# poišče module za export in jih importira
	def poisciExportModule(self):
		package = "PluginsExport"
		self.exportModuliDict = {}
		for a,ime,c in pkgutil.iter_modules([package]):
			modul = importlib.import_module(package + "." + ime)
			self.exportModuliDict[ime] = modul

	# poišče module za povezavo na podatkovno bazo in jih importira
	def poisciDatabaseModule(self):
		package = "PluginsDatabase"
		self.databaseModuliDict = {}
		for a,ime,c in pkgutil.iter_modules([package]):
			modul = importlib.import_module(package + "." + ime)
			self.databaseModuliDict[ime] = modul

	# preveri ali obstajajo direktoriji potrebni za delo programa, če ne obstajajo jih naredi
	def preveriDirektorije(self):
		setupDirektorij = "./"
		workDirektorij = "./"
		self.bazaDirektorij = setupDirektorij + "Baza"
		if not os.path.isdir(self.bazaDirektorij):
			os.makedirs(self.bazaDirektorij)
		self.configDirektorij = setupDirektorij + "Config"
		if not os.path.isdir(self.configDirektorij):
			os.makedirs(self.configDirektorij)
		self.exportPluginsDirektorij = setupDirektorij + "PluginsExport"
		if not os.path.isdir(self.exportPluginsDirektorij):
			os.makedirs(self.exportPluginsDirektorij)
		self.databasePluginsDirektorij = setupDirektorij + "PluginsDatabase"
		if not os.path.isdir(self.databasePluginsDirektorij):
			os.makedirs(self.databasePluginsDirektorij)
		self.izvozDirektorij = setupDirektorij + "Izvoz"
		if not os.path.isdir(self.izvozDirektorij):
			os.makedirs(self.izvozDirektorij)
		self.skenDirektorij = workDirektorij + "Skeni"
		if not os.path.isdir(self.skenDirektorij):
			os.makedirs(self.skenDirektorij)
		self.thumbnailDirektorij = workDirektorij + "Thumbnaili"
		if not os.path.isdir(self.thumbnailDirektorij):
			os.makedirs(self.thumbnailDirektorij)
		self.povecavaDirektorij = workDirektorij + "TmpZoom"
		if not os.path.isdir(self.povecavaDirektorij):
			os.makedirs(self.povecavaDirektorij)
		self.barkodaDirektorij = workDirektorij + "Barkoda"
		if not os.path.isdir(self.barkodaDirektorij):
			os.makedirs(self.barkodaDirektorij)
		self.ocrDirektorij = workDirektorij + "Ocr"
		if not os.path.isdir(self.ocrDirektorij):
			os.makedirs(self.ocrDirektorij)

	# odpremo bazo , če tabele ne obstajajo jih naredimo
	def poveziBazo(self):
		global baza
		baza = sqlite3.connect(self.bazaDirektorij + "/" + "zajem.db")
		bazaUkaz = baza.cursor()
		if not bazaUkaz.execute("SELECT name FROM sqlite_master WHERE type = 'table' AND name = 'Uporabniki'").fetchone():
			print("Tabela Uporabniki ne obstaja!")
			bazaUkaz.execute(
			'''
			CREATE TABLE IF NOT EXISTS Uporabniki
			(
				uporabnik TEXT PRIMARY KEY NOT NULL,
				geslo TEXT,
				ime TEXT,
				priimek TEXT,
				aktiven INTEGER,
				administrator INTEGER,
				skenira INTEGER
			)
			''')
			salt = crypt.mksalt(crypt.METHOD_SHA256) # v tabelo uporabnikov dodamo privzetega uporabnika
			digest = crypt.crypt("zajem",salt)
			podatki = ["administrator","privzeti","uporabnik",digest,True,False,True]
			bazaUkaz.execute(
			'''
				INSERT OR REPLACE INTO Uporabniki
					(uporabnik,ime,priimek,geslo,aktiven,skenira,administrator)
				VALUES
					(?,?,?,?,?,?,?)
			''',podatki)
		if not bazaUkaz.execute("SELECT name FROM sqlite_master WHERE type = 'table' AND name = 'Skenerji'").fetchone():
			print("Tabela Skenerji ne obstaja!")
			bazaUkaz.execute(
			'''
			CREATE TABLE IF NOT EXISTS Skenerji
			(
				skener TEXT PRIMARY KEY
			)
			''')
		if not bazaUkaz.execute("SELECT name FROM sqlite_master WHERE type = 'table' AND name = 'Profili'").fetchone():
			print("Tabela Profili ne obstaja!")
			bazaUkaz.execute(
			'''
			CREATE TABLE IF NOT EXISTS Profili
			(
				id INTEGER PRIMARY KEY,
				skenerId INTEGER,
				profil TEXT
			)
			''')
		if not bazaUkaz.execute("SELECT name FROM sqlite_master WHERE type = 'table' AND name = 'Nastavitve'").fetchone():
			print("Tabela Nastavitve ne obstaja!")
			bazaUkaz.execute(
			'''
			CREATE TABLE IF NOT EXISTS Nastavitve
			(
				profilId INTEGER,
				nastavitev TEXT,
				vrednost TEXT,
				sekcija INTEGER,
				zaporedna INTEGER,
				CONSTRAINT id PRIMARY KEY (profilId,sekcija,zaporedna)
			)
			''')
		if not bazaUkaz.execute("SELECT name FROM sqlite_master WHERE type = 'table' AND name = 'TipiDokumentov'").fetchone():
			print("Tabela TipiDokumentov ne obstaja!")
			bazaUkaz.execute(
			'''
			CREATE TABLE IF NOT EXISTS TipiDokumentov
			(
				tipDokumenta TEXT PRIMARY KEY,
				steviloSkenov INTEGER,
				skener TEXT,
				profil TEXT,
				povezovanje INTEGER,
				povezovanjeModul TEXT,
				izvoz INTEGER,
				izvozModul TEXT,
				crtnaKoda TEXT,
				tesseract INTEGER,
				tesseractJezik TEXT,
				cuneiform INTEGER,
				cuneiformJezik TEXT,
				poljeOcr TEXT,
				xOcr TEXT,
				yOcr TEXT,
				sirinaOcr TEXT,
				visinaOcr TEXT,
				povecava INTEGER
			)
			''')
		if not bazaUkaz.execute("SELECT name FROM sqlite_master WHERE type = 'table' AND name = 'VnosnaPolja'").fetchone():
			print("Tabela VnosnaPolja ne obstaja!")
			bazaUkaz.execute(
			'''
			CREATE TABLE IF NOT EXISTS VnosnaPolja
			(
				id INTEGER PRIMARY KEY,
				idTipDokumenta INTEGER,
				naziv TEXT,
				tip TEXT,
				zaporedna INTEGER
			)
			''')
		if not bazaUkaz.execute("SELECT name FROM sqlite_master WHERE type = 'table' AND name = 'Dokumenti'").fetchone():
			print("Tabela Dokumenti ne obstaja!")
			bazaUkaz.execute(
			'''
			CREATE TABLE IF NOT EXISTS Dokumenti
			(
				dokument TEXT,
				tipDokumentaId TEXT,
				podatki TEXT,
				CONSTRAINT id PRIMARY KEY (dokument,tipDokumentaId)
			)
			''')
		baza.commit()

	# meni
	def initMeni(self):
		# vse akcije
		self.nastavitveUporabnikiAction = QtGui.QAction(u"&Uporabniki",self)
		self.nastavitveUporabnikiAction.triggered.connect(self.pokaziUporabnikiDialog)
		self.nastavitveSkenerjiAction = QtGui.QAction(u"&Skenerji",self)
		self.nastavitveSkenerjiAction.triggered.connect(self.pokaziSkenerjiDialog)
		self.nastavitveTipiDokumentovAction = QtGui.QAction(u"&Tipi dokumentov",self)
		self.nastavitveTipiDokumentovAction.triggered.connect(self.pokaziTipiDokumentovDialog)
		self.skenirajEnListAction = QtGui.QAction(u"Skeniraj &en list",self)
		self.skenirajEnListAction.setEnabled(False)
		self.skenirajEnListAction.triggered.connect(self.skenirajEnList)
		self.skenirajVseListeAction = QtGui.QAction(u"Skeniraj &vse liste",self)
		self.skenirajVseListeAction.setEnabled(False)
		self.skenirajVseListeAction.triggered.connect(self.skenirajVseListe)
		self.brisiListeAction = QtGui.QAction(u"&Briši liste",self)
		self.brisiListeAction.setEnabled(False)
		self.brisiListeAction.triggered.connect(self.brisiListe)
		self.spniListeAction = QtGui.QAction(u"&Spni liste",self)
		self.spniListeAction.triggered.connect(self.spniListe)
		self.raspniListeAction = QtGui.QAction(u"&Raspni liste",self)
		self.raspniListeAction.triggered.connect(self.raspniListe)
		self.izvoziDokumenteAction = QtGui.QAction(u"&Izvozi dokumente",self)
		self.izvoziDokumenteAction.setEnabled(False)
		self.izvoziDokumenteAction.triggered.connect(self.izvoziDokumente)
		self.zapriTipDokumentaAction = QtGui.QAction(u"&Zapri",self)
		self.zapriTipDokumentaAction.setEnabled(False)
		self.zapriTipDokumentaAction.triggered.connect(self.zapriTipDokumenta)
		self.spremeniGesloAction = QtGui.QAction(u"Spremeni &geslo",self)
		self.spremeniGesloAction.triggered.connect(self.pokaziSpremeniGesloDialog)
		self.zapriProgramAction = QtGui.QAction(u"&Zapri",self)
		self.zapriProgramAction.triggered.connect(self.zapriProgram)
		# meni - nastavitve
		self.nastavitveMenu = self.menuBar().addMenu(u"&Nastavitve")
		if administrator:
			self.nastavitveMenu.addAction(self.nastavitveUporabnikiAction)
			self.nastavitveMenu.addAction(self.nastavitveSkenerjiAction)
			self.nastavitveMenu.addAction(self.nastavitveTipiDokumentovAction)
		self.nastavitveMenu.addAction(self.spremeniGesloAction)
		self.nastavitveMenu.addAction(self.zapriProgramAction)
		if skenira:
			# meni - Tip dokumenta
			self.tipDokumentaMenu = self.menuBar().addMenu(u"&Tip dokumenta")
			self.tipiDokumentovSubmenu = QtGui.QMenu(u"&Odpri")
			self.tipDokumentaMenu.addMenu(self.tipiDokumentovSubmenu)
			self.tipDokumentaMenu.addAction(self.zapriTipDokumentaAction)
			# meni - Skeniranje
			self.skeniranjeMenu = self.menuBar().addMenu(u"&Skeniranje")
			self.skeniranjeMenu.addAction(self.skenirajEnListAction)
			self.skeniranjeMenu.addAction(self.skenirajVseListeAction)
			# meni - Brisanje
			self.brisanjeMenu = self.menuBar().addMenu(u"&Brisanje")
			self.brisanjeMenu.addAction(self.brisiListeAction)
			# meni - spenjanje
			self.spenjanjeMenu = self.menuBar().addMenu(u"S&penjanje")
			self.spenjanjeMenu.addAction(self.spniListeAction)
			self.spenjanjeMenu.addAction(self.raspniListeAction)
			# meni - izvoz
			self.izvozMenu = self.menuBar().addMenu(u"&Izvoz")
			self.izvozMenu.addAction(self.izvoziDokumenteAction)

	# glavni del - pogled enega lista
	def initGlavniDel(self):
		slikaDokumentaLabel = ClickLabel()
		self.slikaScrollArea = QtGui.QScrollArea()
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)

	# osveži tipe dokumentov iz podatkovne baze
	def osveziTipeDokumentov(self,updateMeni):
		bazaUkaz = baza.cursor()
		tipiDokumentovList = bazaUkaz.execute(
			'''
				SELECT tipDokumenta
				FROM TipiDokumentov
				ORDER BY tipDokumenta
			''').fetchall()
		for tipDokumenta in tipiDokumentovList:
			action = QtGui.QAction(tipDokumenta[0],self)
			action.triggered.connect(self.izberiTipDokumenta)
			self.orodnaVrsticaTipiToolBar.addAction(action)
			if updateMeni:
				self.tipiDokumentovSubmenu.addAction(action)

	# orodna vrstica tipi
	def initOrodnaVrsticaTipi(self,updateMeni):
		self.orodnaVrsticaTipiToolBar = QtGui.QToolBar()
		self.orodnaVrsticaTipiToolBar.setMovable(False)
		self.osveziTipeDokumentov(updateMeni)

	# orodna vrstica akcije
	def initOrodnaVrsticaAkcije(self):
		self.orodnaVrsticaAkcijeToolBar = QtGui.QToolBar()
		self.orodnaVrsticaAkcijeToolBar.setMovable(False)
		if skenira:
			if self.skener != self.skenerName:
				self.skenirajEnListAction.setEnabled(False)
				self.skenirajVseListeAction.setEnabled(False)
			self.orodnaVrsticaAkcijeToolBar.addAction(self.skenirajEnListAction)
			self.orodnaVrsticaAkcijeToolBar.addAction(self.skenirajVseListeAction)
			self.orodnaVrsticaAkcijeToolBar.addSeparator()
			self.spniListeAction.setEnabled(False)
			self.orodnaVrsticaAkcijeToolBar.addAction(self.spniListeAction)
			self.raspniListeAction.setEnabled(False)
			self.orodnaVrsticaAkcijeToolBar.addAction(self.raspniListeAction)
			self.orodnaVrsticaAkcijeToolBar.addSeparator()
			self.brisiListeAction.setEnabled(False)
			self.orodnaVrsticaAkcijeToolBar.addAction(self.brisiListeAction)
			self.orodnaVrsticaAkcijeToolBar.addSeparator()
			self.orodnaVrsticaAkcijeToolBar.addAction(self.izvoziDokumenteAction)
			self.orodnaVrsticaAkcijeToolBar.addSeparator()
			self.orodnaVrsticaAkcijeToolBar.addAction(self.zapriTipDokumentaAction)

	# vpis podatkov za izbran dokument - levi dock
	def initPodatkiDokumenta(self):
		self.podatkiDockWidget = QtGui.QDockWidget("Podatki dokumenta:")
		self.podatkiDockWidget.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea)
		self.podatkiDockWidget.setFeatures(QtGui.QDockWidget.NoDockWidgetFeatures)
		self.addDockWidget(QtCore.Qt.LeftDockWidgetArea, self.podatkiDockWidget)

	# ikone za delo s sliko dokumenta - desni dock
	def initPogledDokumenta(self):
		self.ikoneDockWidget = QtGui.QDockWidget("Pogled:")
		self.ikoneDockWidget.setAllowedAreas(QtCore.Qt.RightDockWidgetArea)
		self.ikoneDockWidget.setFeatures(QtGui.QDockWidget.NoDockWidgetFeatures)
		self.addDockWidget(QtCore.Qt.RightDockWidgetArea, self.ikoneDockWidget)
		self.ikoneLayout = QtGui.QVBoxLayout()
		self.ikoneWidget = QtGui.QWidget()
		self.ikoneWidget.setLayout(self.ikoneLayout)
		self.slika1proti1PushButton = QtGui.QPushButton("1:1")
		self.slika1proti1PushButton.clicked.connect(self.slika1proti1)
		self.ikoneLayout.addWidget(self.slika1proti1PushButton)
		self.slikaSirinaPushButton = QtGui.QPushButton(u"Širina")
		self.slikaSirinaPushButton.clicked.connect(self.slikaSirina)
		self.ikoneLayout.addWidget(self.slikaSirinaPushButton)
		self.slikaVisinaPushButton = QtGui.QPushButton(u"Višina")
		self.slikaVisinaPushButton.clicked.connect(self.slikaVisina)
		self.ikoneLayout.addWidget(self.slikaVisinaPushButton)
		self.slikaPlusPushButton = QtGui.QPushButton(u"+")
		self.slikaPlusPushButton.clicked.connect(self.slikaPlus)
		self.ikoneLayout.addWidget(self.slikaPlusPushButton)
		self.slikaMinusPushButton = QtGui.QPushButton(u"-")
		self.slikaMinusPushButton.clicked.connect(self.slikaMinus)
		self.ikoneLayout.addWidget(self.slikaMinusPushButton)
		self.slikaLevoPushButton = QtGui.QPushButton(u"Levo")
		self.slikaLevoPushButton.clicked.connect(self.slikaLevo)
		self.ikoneLayout.addWidget(self.slikaLevoPushButton)
		self.slikaDesnoPushButton = QtGui.QPushButton(u"Desno")
		self.slikaDesnoPushButton.clicked.connect(self.slikaDesno)
		self.ikoneLayout.addWidget(self.slikaDesnoPushButton)
		self.ikoneDockWidget.setWidget(self.ikoneWidget)
		self.ikoneDockWidget.setEnabled(False)

	# vrstica z thumbnaili
	def initThumbnails(self):
		self.predogledDockWidget = QtGui.QDockWidget("Dokumenti:",self)
		self.predogledDockWidget.setAllowedAreas(QtCore.Qt.TopDockWidgetArea)
		self.predogledDockWidget.setFeatures(QtGui.QDockWidget.NoDockWidgetFeatures)
		self.addDockWidget(QtCore.Qt.TopDockWidgetArea, self.predogledDockWidget)
		self.predogledWidget = AutoScrollWidget()
		self.predogledLayout = QtGui.QHBoxLayout()
		self.predogledLayout.setSizeConstraint(QtGui.QLayout.SetFixedSize)
		self.predogledWidget.setLayout(self.predogledLayout)
		self.scrollArea = QtGui.QScrollArea()
		self.scrollArea.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
		self.scrollArea.setWidget(self.predogledWidget)
		self.predogledDockWidget.setWidget(self.scrollArea)

	# statusna vrstica
	def initStatusnaVrstica(self):
		self.statusnaVrsticaStatusBar = self.statusBar()
		self.statusnaVrsticaStatusBar.addPermanentWidget(QtGui.QLabel(u"Uporabnik:"))
		self.uporabnikStatusLabel = QtGui.QLabel(uporabnik)
		self.uporabnikStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		self.statusnaVrsticaStatusBar.addPermanentWidget(self.uporabnikStatusLabel)
		self.statusnaVrsticaStatusBar.addPermanentWidget(QtGui.QLabel(u" |  Tip dokumenta:"))
		self.tipDokumentaStatusLabel = QtGui.QLabel("Ni izbran!")
		self.tipDokumentaStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())
		self.statusnaVrsticaStatusBar.addPermanentWidget(self.tipDokumentaStatusLabel)
		self.statusnaVrsticaStatusBar.addPermanentWidget(QtGui.QLabel(u" |  Skener:"))
		self.skenerStatusLabel = QtGui.QLabel("Ni izbran!")
		self.skenerStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())
		self.statusnaVrsticaStatusBar.addPermanentWidget(self.skenerStatusLabel)
		self.statusnaVrsticaStatusBar.addPermanentWidget(QtGui.QLabel(u" |  Profil:"))
		self.profilStatusLabel = QtGui.QLabel("Ni izbran!")
		self.profilStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())
		self.statusnaVrsticaStatusBar.addPermanentWidget(self.profilStatusLabel)
		self.statusnaVrsticaStatusBar.addPermanentWidget(QtGui.QLabel(u" |  Dokumenti:"))
		self.steviloDokumentovStatusLabel = QtGui.QLabel("0")
		self.statusnaVrsticaStatusBar.addPermanentWidget(self.steviloDokumentovStatusLabel)
		self.statusnaVrsticaStatusBar.addPermanentWidget(QtGui.QLabel("/"))
		self.steviloSkenovStatusLabel = QtGui.QLabel("0")
		self.statusnaVrsticaStatusBar.addPermanentWidget(self.steviloSkenovStatusLabel)
		self.statusnaVrsticaStatusBar.addPermanentWidget(QtGui.QLabel(u" |  Status:"))
		self.statusStatusLabel = QtGui.QLabel("Pripravljen")
		self.statusStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		self.statusnaVrsticaStatusBar.addPermanentWidget(self.statusStatusLabel)

	# ********************************************************************************************
	# funkcije za delo s sliko dokumenta
	# ********************************************************************************************

	# izbira dokumentov
	def izberiSliko(self):
		pokaziList = True
		self.slikaWidget = self.sender()
		trenutni = self.predogledLayout.indexOf(self.slikaWidget)
		if self.sender().spet: # klik na list ki je že spet v dokument označi/odznači cel dokument
			if self.sender().izbran: # odznačimo dokument
				for i in self.sender().dokumentList:
					self.predogledLayout.itemAt(i).widget().setNiIzbran()
				for i in range(0,self.podatkiFormLayout.rowCount()): # pobrišemo vnosna polja
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")
				self.brisiListeAction.setEnabled(False)
				self.spniListeAction.setEnabled(False)
				self.raspniListeAction.setEnabled(False)
			else: # označimo dokument
				for i in range(0,self.predogledLayout.count()):
					self.predogledLayout.itemAt(i).widget().setNiIzbran()
				for i in self.sender().dokumentList:
					self.predogledLayout.itemAt(i).widget().setIzbran()
				tmpOd = self.predogledLayout.itemAt(self.sender().dokumentList[0]).widget().dokumentList[0]
				tmpDo = self.predogledLayout.itemAt(self.sender().dokumentList[0]).widget().dokumentList[-1]
				steviloPodatkov = self.podatkiFormLayout.rowCount() # napolnimo vnosna polja s podatki
				podatki = spisekDokumentov[(tmpOd,tmpDo)]
				for i in range(0,steviloPodatkov):
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText(podatki[i])
				self.brisiListeAction.setEnabled(False)
				self.spniListeAction.setEnabled(False)
				self.raspniListeAction.setEnabled(True)
		else: # klik na list ki še ni spet
			if self.sender().select: # k označenim dodamo ali odstranimo enega ali več listov
				self.podatkiFormLayout.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setFocus()
				pokaziList = False
				if self.sender().dodajEnega: # dodamo en list
					if self.sender().izbran:
						self.sender().setNiIzbran()
					else:
						self.sender().setIzbran()
				else: # k označenim dodamo več listov
					zacetek = -1
					for i in range(0,self.predogledLayout.count()):
						if self.predogledLayout.itemAt(i).widget().izbran:
							zacetek = i
							break
					if zacetek > -1:
						if trenutni+1 > zacetek:
							for i in range(zacetek,trenutni+1):
								self.predogledLayout.itemAt(i).widget().setIzbran()
						else:
							for i in range(trenutni,zacetek):
								self.predogledLayout.itemAt(i).widget().setIzbran()
			else: # samo izbiramo list, vse ostale odznačimo
				if self.sender().izbran: # odznačimo en list
					self.sender().setNiIzbran()
					self.brisiListeAction.setEnabled(False)
					self.spniListeAction.setEnabled(False)
					self.raspniListeAction.setEnabled(False)
				else: # označimo en list
					self.sender().setIzbran()
					self.brisiListeAction.setEnabled(True)
					self.spniListeAction.setEnabled(True)
					self.raspniListeAction.setEnabled(False)
					self.podatkiFormLayout.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setFocus()
				for i in range(0,self.predogledLayout.count()):
					if trenutni != i:
						self.predogledLayout.itemAt(i).widget().setNiIzbran()
				for i in range(0,self.podatkiFormLayout.rowCount()): # pobrišemo vnosna polja
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setStyleSheet("")
		if pokaziList:# pokaže sliko ki smo jo kliknili
			self.ikoneDockWidget.setEnabled(True)
			self.skenDatoteka = self.sender().text() +  ".pnm"
			self.pokaziPovecano()

	# pokaže pravilno povečano sliko
	def pokaziPovecano(self):
		if 1 == self.povecava:
			self.slikaPlus()
		if 2 == self.povecava:
			self.slikaSirina()
		if 3 == self.povecava:
			self.slika1proti1()
		if 4 == self.povecava:
			self.slikaVisina()
		if 5 == self.povecava:
			self.slikaMinus()	
			
	# povečava ena proti ena
	def slika1proti1(self):
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		zoomDatotekaFD = open(self.povecavaDirektorij + "/"  + self.skenDatoteka ,"w")
		subprocess.call(["pamscale","0.3",self.skenDirektorijTip + self.skenDatoteka], stdout = zoomDatotekaFD, stderr = errorDatotekaFD)
		zoomDatotekaFD.close()
		errorDatotekaFD.close()
		slikaDokumentaPixmap = QtGui.QPixmap(self.povecavaDirektorij + "/" + self.skenDatoteka)
		slikaDokumentaLabel = ClickLabel()
		slikaDokumentaLabel.setPixmap(slikaDokumentaPixmap)
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)

	# povečava širina dokumenta
	def slikaSirina(self):
		slikaDokumentaPixmap = QtGui.QPixmap(self.skenDirektorijTip + self.skenDatoteka)
		faktor =  round(1.0 * self.slikaScrollArea.viewport().size().width() / slikaDokumentaPixmap.size().width(),3)
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		zoomDatotekaFD = open(self.povecavaDirektorij + "/" + self.skenDatoteka ,"w")
		subprocess.call(["pamscale",str(faktor),self.skenDirektorijTip + self.skenDatoteka], stdout = zoomDatotekaFD, stderr = errorDatotekaFD)
		zoomDatotekaFD.close()
		errorDatotekaFD.close()
		slikaDokumentaPixmap = QtGui.QPixmap(self.povecavaDirektorij + "/"  + self.skenDatoteka)
		slikaDokumentaLabel = ClickLabel()
		slikaDokumentaLabel.setPixmap(slikaDokumentaPixmap)
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)

	# povečava višina dokumenta
	def slikaVisina(self):
		slikaDokumentaPixmap = QtGui.QPixmap(self.skenDirektorijTip + self.skenDatoteka)
		faktor =  round(1.0 * self.slikaScrollArea.viewport().size().height() / slikaDokumentaPixmap.size().height(),3)
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		zoomDatotekaFD = open(self.povecavaDirektorij + "/" + self.skenDatoteka ,"w")
		subprocess.call(["pamscale",str(faktor),self.skenDirektorijTip + self.skenDatoteka], stdout = zoomDatotekaFD, stderr = errorDatotekaFD)
		zoomDatotekaFD.close()
		errorDatotekaFD.close()
		slikaDokumentaPixmap = QtGui.QPixmap(self.povecavaDirektorij + "/" + self.skenDatoteka)
		slikaDokumentaLabel = ClickLabel()
		slikaDokumentaLabel.setPixmap(slikaDokumentaPixmap)
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)

	# povečava največja slika
	def slikaPlus(self):
		slikaDokumentaPixmap = QtGui.QPixmap(self.skenDirektorijTip + self.skenDatoteka)
		slikaDokumentaLabel = ClickLabel()
		slikaDokumentaLabel.setPixmap(slikaDokumentaPixmap)
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)

	# povečava najmanjša slika
	def slikaMinus(self):
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		zoomDatotekaFD = open(self.povecavaDirektorij + "/" + self.skenDatoteka ,"w")
		subprocess.call(["pamscale","0.2",self.skenDirektorijTip + self.skenDatoteka], stdout = zoomDatotekaFD, stderr = errorDatotekaFD)
		zoomDatotekaFD.close()
		errorDatotekaFD.close()
		slikaDokumentaPixmap = QtGui.QPixmap(self.povecavaDirektorij + "/" + self.skenDatoteka)
		slikaDokumentaLabel = ClickLabel()
		slikaDokumentaLabel.setPixmap(slikaDokumentaPixmap)
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)

	# zavrti sliko v levo
	def slikaLevo(self):
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		zoomDatotekaFD = open(self.povecavaDirektorij + "/" + self.skenDatoteka ,"w")
		subprocess.call(["pamflip","-rotate90",self.skenDirektorijTip + self.skenDatoteka], stdout = zoomDatotekaFD, stderr = errorDatotekaFD)
		zoomDatotekaFD.close()
		errorDatotekaFD.close()
		shutil.copyfile(self.povecavaDirektorij + "/" + self.skenDatoteka,self.skenDirektorijTip + self.skenDatoteka)
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		thumbnailDatotekaFD = open(self.thumbnailDirektorijTip + self.skenDatoteka,"w")
		subprocess.call(["pamscale","0.0625",self.skenDirektorijTip + self.skenDatoteka], stdout = thumbnailDatotekaFD, stderr = errorDatotekaFD)
		thumbnailDatotekaFD.close()
		errorDatotekaFD.close()
		self.predogledWidget.autoScroll = False
		ikona = QtGui.QIcon(self.thumbnailDirektorijTip + self.skenDatoteka)
		self.slikaWidget.setIcon(ikona)
		self.slikaWidget.setIconSize(ikona.availableSizes()[0])
		self.slikaWidget.setMinimumSize(self.slikaWidget.sizeHint())
		self.pokaziPovecano()

	# zavrti sliko v desno
	def slikaDesno(self):
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		zoomDatotekaFD = open(self.povecavaDirektorij + "/" + self.skenDatoteka ,"w")
		subprocess.call(["pamflip","-rotate270",self.skenDirektorijTip + self.skenDatoteka], stdout = zoomDatotekaFD, stderr = errorDatotekaFD)
		zoomDatotekaFD.close()
		errorDatotekaFD.close()
		shutil.copyfile(self.povecavaDirektorij + "/" + self.skenDatoteka,self.skenDirektorijTip + self.skenDatoteka)
		errorDatotekaFD = open(self.configDirektorij + "/" + "error.log","w")
		thumbnailDatotekaFD = open(self.thumbnailDirektorijTip + self.skenDatoteka,"w")
		subprocess.call(["pamscale","0.0625",self.skenDirektorijTip + self.skenDatoteka], stdout = thumbnailDatotekaFD, stderr = errorDatotekaFD)
		thumbnailDatotekaFD.close()
		errorDatotekaFD.close()
		self.predogledWidget.autoScroll = False
		ikona = QtGui.QIcon(self.thumbnailDirektorijTip + self.skenDatoteka)
		self.slikaWidget.setIcon(ikona)
		self.slikaWidget.setIconSize(ikona.availableSizes()[0])
		self.slikaWidget.setMinimumSize(self.slikaWidget.sizeHint())
		self.pokaziPovecano()

	# ********************************************************************************************
	# funkcije menija
	# ********************************************************************************************

	# prikaže dialog Nastavitve -> Uporabniki
	def pokaziUporabnikiDialog(self):
		uporabnikiDialog = UporabnikiDialog(self)
		uporabnikiDialog.exec_()

	# prikaže dialog Nastavitve -> Skenerji
	def pokaziSkenerjiDialog(self):
		if self.skenerName:
			skenerjiDialog = SkenerjiDialog(self)
			skenerjiDialog.exec_()
		else:
			napakaDialog = NapakaDialog(self,"Skener se da nastavljati \n samo če je priključen!")
			napakaDialog.exec_()

	# prikaže dialog Nastavitve -> TipiDokumentov
	def pokaziTipiDokumentovDialog(self):
		tipiDokumentovDialog = TipiDokumentovDialog(self)
		tipiDokumentovDialog.exec_()

	# prikaže dialog Nastavitve -> SpremeniGeslo
	def pokaziSpremeniGesloDialog(self):
		spremeniGesloDialog = SpremeniGesloDialog(self)
		spremeniGesloDialog.exec_()

	# zapre program Nastavitve -> Zapri
	def zapriProgram(self):
		sys.exit()

	# ********************************************************************************************
	# funkcije orodne vrstice
	# ********************************************************************************************

	# uporabnik je izbral tip dokumenta
	def izberiTipDokumenta(self):
		self.tipDokumenta = self.sender().text()
		self.podatkiWidget = QtGui.QWidget()
		self.podatkiFormLayout = QtGui.QFormLayout()
		self.podatkiWidget.setLayout(self.podatkiFormLayout)
		self.podatkiDockWidget.setWidget(self.podatkiWidget)
		self.poljaDokumentaExportList = []
		bazaUkaz = baza.cursor() # iz baze preberemo polja za izbran tip dokumenta 
		poljaDokumentaList = bazaUkaz.execute(
		'''
			SELECT naziv,tip
			FROM VnosnaPolja,TipiDokumentov
			WHERE idTipDokumenta = TipiDokumentov.rowid AND tipDokumenta = ?
			ORDER BY zaporedna
		''',(self.tipDokumenta,)).fetchall()
		prvi = True
		for polje in poljaDokumentaList: 
			lineEdit = QtGui.QLineEdit()
			if "Besedilo" == polje[1]:
				lineEdit.setValidator(BesediloValidator())
			if "Datum" == polje[1]:
				lineEdit.setInputMask("00.00.0000")
				lineEdit.setValidator(DatumValidator())
			if "Vrednost" == polje[1]:
				lineEdit.setValidator(VrednostValidator())
			lineEdit.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
			if prvi:
				lineEdit.editingFinished.connect(self.poisciIzBaze)
				prvi = False
			self.podatkiFormLayout.addRow(polje[0],lineEdit)
			self.poljaDokumentaExportList.append(polje)
		nastavitve = bazaUkaz.execute( # iz baze preberemo skener,profil,stevilo skenov,način vezave sta izbrana za ta tip dokumenta
		'''
			SELECT skener,profil,steviloSkenov,povezovanje,povezovanjeModul,povecava,crtnaKoda,izvoz,izvozModul,tesseract,tesseractJezik,cuneiform,cuneiformJezik,poljeOcr,xOcr,yOcr,sirinaOcr,visinaOcr
			FROM TipiDokumentov
			WHERE tipDokumenta = ?
		''',(self.tipDokumenta,)).fetchone()
		self.skener = nastavitve[0]
		self.profil = nastavitve[1]
		self.steviloSkenov = nastavitve[2] + 1
		self.povezovanje = nastavitve[3]
		self.povezovanjeModul = nastavitve[4]
		self.povecava = nastavitve[5]
		self.crtnaKodaList = eval(nastavitve[6])
		self.izvoz = nastavitve[7]
		self.izvozModul = nastavitve[8]
		self.tesseract = nastavitve[9]
		self.tesseractJezik = nastavitve[10]
		self.cuneiform = nastavitve[11]
		self.cuneiformJezik = nastavitve[12]
		self.poljeOcr = nastavitve[13]
		self.xOcr = nastavitve[14]
		self.yOcr = nastavitve[15]
		self.sirinaOcr = nastavitve[16]
		self.visinaOcr = nastavitve[17]
		self.skenDirektorijTip = self.skenDirektorij + "/" + self.tipDokumenta + "/"
		if not os.path.isdir(self.skenDirektorijTip):
			os.makedirs(self.skenDirektorijTip)
		self.thumbnailDirektorijTip = self.thumbnailDirektorij + "/" + self.tipDokumenta + "/"
		if not os.path.isdir(self.thumbnailDirektorijTip):
			os.makedirs(self.thumbnailDirektorijTip)
			skeni = []
		else:
			self.predogledWidget.autoScroll = False
			skeni = os.listdir(self.thumbnailDirektorijTip) # če imamo za ta tip dokumeta že kaj skenov jih dodamo v thumbnail vrstico
			skeni.sort()
			maxHeight = 0
			for sken in skeni:
				thumbnailDatoteka = self.thumbnailDirektorijTip + sken
				gumbToolButton = ThumbnailToolButton(thumbnailDatoteka)
				gumbToolButton.clicked.connect(self.izberiSliko)
				self.predogledLayout.addWidget(gumbToolButton)
				maxHeight = max(maxHeight,gumbToolButton.sizeHint().height())
			top = self.predogledLayout.contentsMargins().top()
			bottom = self.predogledLayout.contentsMargins().bottom()
			self.predogledDockWidget.setFixedHeight(maxHeight + top + bottom + 40) # zakaj je treba dodati 40?
		dokumenti = bazaUkaz.execute( # iz baze preberemo kateri dokumenti so speti za ta tip dokumenta
		'''
			SELECT dokument,podatki
			FROM Dokumenti
			WHERE tipDokumentaId = ?
		''',(self.tipDokumenta,)).fetchall()
		dokumenti.sort()
		barve = [1,2]
		n = 0
		for d in dokumenti:
			dokument = eval(d[0])
			podatki = eval(d[1])
			izbrani = []
			for i in range(dokument[0],dokument[1] + 1):
				izbrani.append(i)
			for i in range(dokument[0],dokument[1] + 1):
				self.predogledLayout.itemAt(i).widget().spniList(barve[n % 2])
				self.predogledLayout.itemAt(i).widget().dokumentList = izbrani
			spisekDokumentov[dokument] = podatki
			n += 1
		self.removeToolBar(self.orodnaVrsticaTipiToolBar)
		self.initOrodnaVrsticaAkcije()
		self.addToolBar(self.orodnaVrsticaAkcijeToolBar)
		self.zapriTipDokumentaAction.setEnabled(True)
		self.izvoziDokumenteAction.setEnabled(True)
		self.tipiDokumentovSubmenu.setEnabled(False)
		self.tipDokumentaStatusLabel.setText(self.tipDokumenta) # spremenimo statusno vrstico
		self.tipDokumentaStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		self.profilStatusLabel.setText(self.profil)
		self.profilStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		self.skenerStatusLabel.setText(self.skener)
		if self.skener == self.skenerName:
			self.skenerStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
			self.razlikaSkenOpcij()
			self.skenirajEnListAction.setEnabled(True)
			self.skenirajVseListeAction.setEnabled(True)
		else:
			self.skenerStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())
		self.steviloDokumentovStatusLabel.setText(str(len(dokumenti)))	
		self.steviloSkenovStatusLabel.setText(str(len(skeni)))	

	# poišče vrednosti ostalih polj iz baze
	def poisciIzBaze(self):
		ident = self.podatkiFormLayout.itemAt(0,QtGui.QFormLayout.FieldRole).widget().text()
		if self.povezovanjeModul in self.databaseModuliDict:
			resultList = self.databaseModuliDict[self.povezovanjeModul].poisci(ident)
			for i in range(1,self.podatkiFormLayout.rowCount()):
				if len(resultList) > 0:
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText(resultList.pop(0))
				else:
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")

	# skenira en list
	def skenirajEnList(self):
		self.skenirajEnListThread = SkenirajEnListThread()
		self.skenirajEnListThread.started.connect(self.skenirajEnListStart)
		self.skenirajEnListThread.finished.connect(self.skenirajEnListFinish)
		self.skenirajEnListThread.start()

	# skenira vse liste iz podajalca
	def skenirajVseListe(self):
		self.skenirajVseListeThread = SkenirajVseListeThread()
		self.skenirajVseListeThread.started.connect(self.skenirajVseListeStart)
		self.skenirajVseListeThread.finished.connect(self.skenirajVseListeFinish)
		self.skenirajVseListeThread.start()

	# briše izbrane liste
	def brisiListe(self):
		izbrani = []
		for i in range(0,self.predogledLayout.count()):
			if self.predogledLayout.itemAt(i).widget().izbran:
				izbrani.append(i)
		if len(izbrani):
			tmpSpeti = list(sorted(spisekDokumentov.keys()))
			if (not tmpSpeti) or (tmpSpeti[-1][-1] < izbrani[-1]): # listov ne moremo brisati če je za njimi spet dokument
				for i in izbrani:
					deleteWidget = self.predogledLayout.itemAt(i).widget()
					indeks = deleteWidget.text()
					deleteWidget.deleteLater()
					deleteDatoteka = self.skenDirektorij + "/" + self.tipDokumenta + "/" + indeks +".pnm"
					os.remove(deleteDatoteka)
					deleteDatoteka = self.thumbnailDirektorij + "/" + self.tipDokumenta + "/" + indeks +".pnm"
					os.remove(deleteDatoteka)
					self.steviloSkenovStatusLabel.setText(str(int(self.steviloSkenovStatusLabel.text()) - 1))
				for i in range(0,self.podatkiFormLayout.rowCount()): # pobrišemo vnosna polja
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setStyleSheet("")
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().clearFocus()
				slikaDokumentaLabel = ClickLabel() # pobriše sliko dokumenta
				self.slikaScrollArea.setWidget(slikaDokumentaLabel)
				self.setCentralWidget(self.slikaScrollArea)
			else:
				napakaDialog = NapakaDialog(self,"Liste lahko brišemo samo,\n če za njimi ni spetih dokumentov !")
				napakaDialog.exec_()
		else:
			napakaDialog = NapakaDialog(self,"Ni izbranih listov za brisanje!")
			napakaDialog.exec_()

	# spni izbrane liste v dokument
	def spniListe(self):
		izbrani = []
		barve = [1,2,3]
		for i in range(0,self.predogledLayout.count()):
			if self.predogledLayout.itemAt(i).widget().izbran:
				izbrani.append(i)
		if len(izbrani):
			zacetek = izbrani[0]-1
			konec = izbrani [-1]+1
			if zacetek > -1: # ce obstaja list na levi in je spet, odstrani njegovo barvo iz seznama barv
				barva = self.predogledLayout.itemAt(zacetek).widget().spet
				if barve.count(barva):
					barve.remove(barva)
			if konec < self.predogledLayout.count(): # ce obstaja list na desni in je spet, odstani njegovo barvo iz seznama barv
				barva = self.predogledLayout.itemAt(konec).widget().spet
				if barve.count(barva):
					barve.remove(barva)
			pravilni = True
			for i in range(0,self.podatkiFormLayout.rowCount()): # preveri ali so podatki v vnosnih poljih pravilni
				pravilen = self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().hasAcceptableInput()
				if pravilen:
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setStyleSheet("")
				else:	
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setStyleSheet("QLineEdit { background-color: %s }" %QtGui.QColor(230,150,150).name())
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setFocus()
				pravilni = pravilni and pravilen
			if pravilni:	
				for i in izbrani: # vse izbrane liste spni z prvo barvo iz seznama barv
					self.predogledLayout.itemAt(i).widget().spniList(barve[0])
					self.predogledLayout.itemAt(i).widget().dokumentList = izbrani
					podatki = [] # v spisek dokumentov damo id dokumenta in listo s podatki
				for i in range(0,self.podatkiFormLayout.rowCount()):
					podatki.append(self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().text())
					self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().clearFocus()
				dokument = (izbrani[0],izbrani[-1])
				spisekDokumentov[dokument] = podatki
				bazaUkaz = baza.cursor()
				bazaUkaz.execute(
				'''
					INSERT OR REPLACE INTO Dokumenti
						(dokument,tipDokumentaId,podatki)
					VALUES (?,?,?)
				''',[repr(dokument),self.tipDokumenta,repr(podatki)])
				baza.commit()
				self.steviloDokumentovStatusLabel.setText(str(int(self.steviloDokumentovStatusLabel.text()) + 1))
				self.brisiListeAction.setEnabled(False)
				self.spniListeAction.setEnabled(False)
		else:
			napakaDialog = NapakaDialog(self,"Ni izbranih listov za spenjanje!")
			napakaDialog.exec_()

	# razpni izbran dokument v liste
	def raspniListe(self):
		izbrani = []
		for i in range(0,self.predogledLayout.count()):
			if self.predogledLayout.itemAt(i).widget().izbran:
				izbrani.append(i)
		if len(izbrani):
			for i in izbrani: # s tem ko dokumentList postavimo na [] razpnemo liste
				self.predogledLayout.itemAt(i).widget().razpniList()
				self.predogledLayout.itemAt(i).widget().dokumentList = []
				self.predogledLayout.itemAt(i).widget().setNiIzbran()
			dokument = (izbrani[0],izbrani[-1])
			del spisekDokumentov[dokument] # odstranimo dokument iz spiska dokumentov in baze
			bazaUkaz = baza.cursor()
			bazaUkaz.execute(
			'''
				DELETE FROM Dokumenti 
				WHERE dokument = ? AND tipDokumentaId = ?
			''',[str(dokument),self.tipDokumenta])
			baza.commit()
			for i in range(0,self.podatkiFormLayout.rowCount()): # pobrišemo vnosna polja
				self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")
			self.steviloDokumentovStatusLabel.setText(str(int(self.steviloDokumentovStatusLabel.text()) - 1))
		else:
			napakaDialog = NapakaDialog(self,"Ni izbranih listov za razpenjanje!")
			napakaDialog.exec_()

	# izvozi vse povezane dokumente
	def izvoziDokumente(self):
		if spisekDokumentov:
			self.izvoziDokumenteThread = IzvoziDokumenteThread()
			self.izvoziDokumenteThread.started.connect(self.izvozStart)
			self.izvoziDokumenteThread.finished.connect(self.izvozFinish)
			self.izvoziDokumenteThread.start()
		else:
			napakaDialog = NapakaDialog(self,"Ni dokumentov za izvoz!")
			napakaDialog.exec_()

	# zapre tip dokumenta
	def zapriTipDokumenta(self):
		self.tipDokumenta = None
		for i in range(0,self.podatkiFormLayout.count()): # izbriše obstoječa polja
			widget = self.podatkiFormLayout.takeAt(0).widget()
			widget.deleteLater()
		self.removeToolBar(self.orodnaVrsticaAkcijeToolBar)
		for i in range(0,self.predogledLayout.count()): # izbriše thumbnail dokumente
			widget = self.predogledLayout.takeAt(0).widget()
			widget.deleteLater()
		self.initOrodnaVrsticaTipi(False)
		self.addToolBar(self.orodnaVrsticaTipiToolBar)
		self.tipDokumentaStatusLabel.setText(u"Ni izbran") # nastavi status
		self.tipDokumentaStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())
		self.profilStatusLabel.setText(u"Ni izbran")
		self.profilStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())
		if self.skenerName:
			self.skenerStatusLabel.setText(self.skenerName)
			self.skenerStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		else:
			self.skenerStatusLabel.setText(u"Ni izbran")
			self.skenerStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())
		self.steviloSkenovStatusLabel.setText("0")	
		slikaDokumentaLabel = ClickLabel() # pobriše sliko dokumenta
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)
		self.ikoneDockWidget.setEnabled(False)
		self.zapriTipDokumentaAction.setEnabled(False)
		self.tipiDokumentovSubmenu.setEnabled(True)
		self.skenirajEnListAction.setEnabled(False)
		self.skenirajVseListeAction.setEnabled(False)
		self.izvoziDokumenteAction.setEnabled(False)

	# ********************************************************************************************
	# funkcije povezane z opravili ki se izvajajo v drugih tread-ih
	# ********************************************************************************************

	# začetek iskanja skenerja
	def isciSkenerStart(self):
		self.statusStatusLabel.setText(u"Iščemo skener")
		self.statusStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(250,100,100).name())
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.WaitCursor)
		program.setOverrideCursor(cursor)

	# konec iskanja skenerja
	def isciSkenerFinish(self):
		self.statusStatusLabel.setText(u"Pripravljen")
		self.statusStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.ArrowCursor)
		program.setOverrideCursor(cursor)
		if self.skenerName:
			self.skenerStatusLabel.setText(self.skenerName)
			self.skenerStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		else:
			self.skenerStatusLabel.setText("Ni izbran")
			self.skenerStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(230,150,150).name())

	# začetek skeniranja - en list
	def skenirajEnListStart(self):
		self.prviSken = self.steviloSkenov
		self.statusStatusLabel.setText(u"Skeniramo")
		self.statusStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,150,230).name())
		self.skenirajEnListAction.setEnabled(False)
		self.skenirajVseListeAction.setEnabled(False)
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.WaitCursor)
		program.setOverrideCursor(cursor)

	# konec skeniranja - en list
	def skenirajEnListFinish(self):
		if self.steviloSkenov > self.prviSken:
			self.predogledWidget.autoScroll = True
			imeDatoteke = "{0:04d}.pnm".format(self.steviloSkenov - 1)
			thumbnailDirektorijTip = self.thumbnailDirektorij + "/" + self.tipDokumenta + "/"
			thumbnailDatoteka = thumbnailDirektorijTip + imeDatoteke
			gumbToolButton = ThumbnailToolButton(thumbnailDatoteka)
			gumbToolButton.clicked.connect(self.izberiSliko)
			gumbToolButton.click()
			if 3 == self.povezovanje:
				crtnaKoda = self.citajCrtnoKodo(imeDatoteke)
				self.podatkiFormLayout.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setText(crtnaKoda)
			if 4 == self.povezovanje:
				tmpX0 = decimal.Decimal(glavnoOkno.xOcr)
				tmpY0 = decimal.Decimal(glavnoOkno.yOcr)
				tmpX1 = tmpX0 + decimal.Decimal(glavnoOkno.sirinaOcr)
				tmpY1 = tmpY0 + decimal.Decimal(glavnoOkno.visinaOcr)
				self.centralWidget().widget().preberi(min(tmpX0 , tmpX1),min(tmpY0 , tmpY1),max(tmpX0 , tmpX1),max(tmpY0 , tmpY1))
			self.predogledLayout.addWidget(gumbToolButton)
			maxHeight = gumbToolButton.sizeHint().height()
			top = self.predogledLayout.contentsMargins().top()
			bottom = self.predogledLayout.contentsMargins().bottom()
			self.predogledDockWidget.setFixedHeight(maxHeight + top + bottom + 40) # zakaj je treba dodati 40?
			bazaUkaz = baza.cursor()
			bazaUkaz.execute(
			'''
				UPDATE TipiDokumentov 
				SET steviloSkenov = ? 
				WHERE tipDokumenta = ?
			''',[self.steviloSkenov - 1,self.tipDokumenta])
			baza.commit()
			self.steviloSkenovStatusLabel.setText(str(int(self.steviloSkenovStatusLabel.text()) + 1))
		self.skenirajEnListAction.setEnabled(True)
		self.skenirajVseListeAction.setEnabled(True)
		self.statusStatusLabel.setText(u"Pripravljen")
		self.statusStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.ArrowCursor)
		program.setOverrideCursor(cursor)

	# začetek skeniranja - vsi listi v podajalcu
	def skenirajVseListeStart(self):
		self.prviSken = self.steviloSkenov
		self.statusStatusLabel.setText(u"Skeniramo")
		self.statusStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,150,230).name())
		self.skenirajEnListAction.setEnabled(False)
		self.skenirajVseListeAction.setEnabled(False)
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.WaitCursor)
		program.setOverrideCursor(cursor)

	# konec skeniranja - vsi listi v podajalcu
	def skenirajVseListeFinish(self):
		if self.steviloSkenov > self.prviSken:
			thumbnailDirektorijTip = self.thumbnailDirektorij + "/"  + self.tipDokumenta + "/"
			maxHeight = 0
			self.predogledWidget.autoScroll = True
			for i in range(self.prviSken,self.steviloSkenov):
				imeDatoteke = "{0:04d}.pnm".format(i)
				thumbnailDatoteka = thumbnailDirektorijTip + imeDatoteke
				gumbToolButton = ThumbnailToolButton(thumbnailDatoteka)
				gumbToolButton.clicked.connect(self.izberiSliko)
				if i == self.prviSken:
					gumbToolButton.click()
					if 3 == self.povezovanje:
						crtnaKoda = self.citajCrtnoKodo(imeDatoteke)
						self.podatkiFormLayout.itemAt(0,QtGui.QFormLayout.FieldRole).widget().setText(crtnaKoda)
					if 4 == self.povezovanje:
						tmpX0 = decimal.Decimal(glavnoOkno.xOcr)
						tmpY0 = decimal.Decimal(glavnoOkno.yOcr)
						tmpX1 = tmpX0 + decimal.Decimal(glavnoOkno.sirinaOcr)
						tmpY1 = tmpY0 + decimal.Decimal(glavnoOkno.visinaOcr)
						self.centralWidget().widget().preberi(min(tmpX0 , tmpX1),min(tmpY0 , tmpY1),max(tmpX0 , tmpX1),max(tmpY0 , tmpY1))
				if 2 == self.povezovanje or 3 == self.povezovanje or 4 == self.povezovanje:
					gumbToolButton.setIzbran()
				self.predogledLayout.addWidget(gumbToolButton)
				maxHeight = max(maxHeight,gumbToolButton.sizeHint().height())
				self.steviloSkenovStatusLabel.setText(str(int(self.steviloSkenovStatusLabel.text()) + 1))
			top = self.predogledLayout.contentsMargins().top()
			bottom = self.predogledLayout.contentsMargins().bottom()
			self.predogledDockWidget.setFixedHeight(maxHeight + top + bottom + 40) # zakaj je treba dodati 40?
			bazaUkaz = baza.cursor()
			bazaUkaz.execute(
			'''
				UPDATE TipiDokumentov 
				SET steviloSkenov = ? 
				WHERE tipDokumenta = ?
			''',[self.steviloSkenov - 1,self.tipDokumenta])
			baza.commit()
		self.skenirajEnListAction.setEnabled(True)
		self.skenirajVseListeAction.setEnabled(True)
		self.statusStatusLabel.setText(u"Pripravljen")
		self.statusStatusLabel.setStyleSheet("QLabel { background-color: %s }" %QtGui.QColor(150,230,150).name())
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.ArrowCursor)
		program.setOverrideCursor(cursor)
		
	# poišče črtno kodo če je tip črtne kode omogočen v nastavitvah profila
	def citajCrtnoKodo(self,imeDatoteke):
		barkodaDirektorijTip =  self.barkodaDirektorij + "/"  + self.tipDokumenta + "/"
		if not os.path.isdir(barkodaDirektorijTip):
			os.makedirs(barkodaDirektorijTip)
		crtnaKodaEnabledList = []
		crtnaKodaTipi = [u"ean13",u"ean8",u"upca",u"upce",u"isbn10",u"isbn13",u"i25",u"codabar",u"code39",u"code93",u"code128",u"qrcode"]
		for i in range(0,len(crtnaKodaTipi)):
			if self.crtnaKodaList[i]:
				crtnaKodaEnabledList.append(crtnaKodaTipi[i])
		zbarimgCallList = ["zbarimg","-q","-Sdisable"]
		for koda in crtnaKodaEnabledList:
			zbarimgCallList.append("-S" + koda + ".enable")
		zbarimgCallList.append(self.skenDirektorijTip + imeDatoteke)
		barkodaDatoteka = open(barkodaDirektorijTip + imeDatoteke + ".txt","w")
		subprocess.call(zbarimgCallList, stdout = barkodaDatoteka)
		barkodaDatoteka = open(barkodaDirektorijTip + imeDatoteke + ".txt","r")
		barkodaText = barkodaDatoteka.read()
		barkodaDatoteka.close()
		barkodaTextList = barkodaText.split(":")
		if 2 == len(barkodaTextList):
			return barkodaTextList[1].strip()
		else:
			return ""
			
	# začetek izvoza povezanih dokumentov
	def izvozStart(self):
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.WaitCursor)
		program.setOverrideCursor(cursor)
		self.izvozDialog = IzvozDialog(self)
		self.izvozDialog.open()

	# konec izvoza povezanih dokumentov
	def izvozFinish(self):
		dokumentiList = list(sorted(spisekDokumentov.keys())) # naredimo spisek dokumentov
		dokumentiList.reverse() # brišemo jih od konca proti začetku
		for dokument in dokumentiList: # pobrišemo dokumente iz thumbnail vrstice
			for stran in range(dokument[1],dokument[0]-1,-1):
				deleteWidget = self.predogledLayout.itemAt(stran).widget()
				indeks = deleteWidget.text()
				deleteWidget.deleteLater()
				deleteDatoteka = self.skenDirektorij + "/" + self.tipDokumenta + "/" + indeks + ".pnm"
				os.remove(deleteDatoteka)
				deleteDatoteka = self.thumbnailDirektorij + "/" + self.tipDokumenta + "/" + indeks + ".pnm"
				os.remove(deleteDatoteka)
			bazaUkaz = baza.cursor() # pobrišemo dokumente iz baze
			bazaUkaz.execute(
			'''
				DELETE FROM Dokumenti 
				WHERE dokument = ? AND tipDokumentaId = ?
			''',[str(dokument),glavnoOkno.tipDokumenta])
			baza.commit()
		dokumentiList = {}
		for i in range(0,self.podatkiFormLayout.rowCount()): # pobrišemo vnosna polja
			self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setText("")
			self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().setStyleSheet("")
			self.podatkiFormLayout.itemAt(i,QtGui.QFormLayout.FieldRole).widget().clearFocus()
		slikaDokumentaLabel = ClickLabel() # pobriše sliko dokumenta
		self.slikaScrollArea.setWidget(slikaDokumentaLabel)
		self.setCentralWidget(self.slikaScrollArea)
		cursor = QtGui.QCursor()
		cursor.setShape(QtCore.Qt.ArrowCursor)
		program.setOverrideCursor(cursor)

	# ********************************************************************************************
	# funkcije za nastavitve skenerja
	# ********************************************************************************************
		
	# parsamo scanimage -A za izbrani skener v listo scanimageOpcije
	def poisciNastavitveSkenerja(self):
		scanimageAllDatoteka = open(self.configDirektorij + "/" + self.skenerName + ".txt","r")
		scanimageSkenerAll = scanimageAllDatoteka.read()
		scanimageSkenerAllList = scanimageSkenerAll.split("\n")
		scanimageAllDatoteka.close()
		scanimageSkenerAllList.pop(0) # prvi dve vrstici sta odveč
		scanimageSkenerAllList.pop(0)
		scanimageSkenerAllList.pop() # zadnji dve vrstici sta odveč
		scanimageSkenerAllList.pop()
		self.scanimageOpcije = []
		for vrstica in scanimageSkenerAllList:
			if ":" in vrstica: # tab
				self.scanimageOpcije.append([[vrstica.strip()]])
			else: # opcija
				opcija = vrstica.lstrip().split(" ",1)[0]
				tmpVrstica = vrstica.lstrip().split(" ",1)[1]
				vrednost = tmpVrstica.rsplit("[",1)[-1].rstrip("]")
				tmpVrstica = tmpVrstica.rsplit("[",1)[0]
				if "=" in opcija: # boolean
					opcijaBoolean = opcija.split("(",1)
					opcija = opcijaBoolean[0].replace("[","")
					tmpVrstica = opcijaBoolean[1].replace("]","").replace(")","")
				if vrednost in ("read-only","hardware"): # dodatni parametri
					vrednost = vrstica.rsplit("[")[-2].rstrip(" ").rstrip("]")
					tmpVrstica = tmpVrstica.rsplit("[",1)[0]
				if opcija[0] == "-": # opcija
					self.scanimageOpcije[-1].append([opcija,vrednost,tmpVrstica])
				else: # opis
					self.scanimageOpcije[-1][-1].append(vrstica.strip())

	# poiščemo razlike med privzetimi nastavitvami za skener in dejansko izbiro v profilu za skeniranje
	def razlikaSkenOpcij(self):
		izbranProfil = self.profil
		izbranSkener = self.skener
		bazaUkaz = baza.cursor()
		nastavitve = bazaUkaz.execute(
		'''
			SELECT nastavitev,vrednost FROM Skenerji,Profili,Nastavitve
			WHERE skener = ?
			AND profil = ?
			AND Profili.SkenerId = Skenerji.rowid
			AND Nastavitve.profilId = Profili.id
			ORDER BY Nastavitve.sekcija,Nastavitve.zaporedna
		''',[izbranSkener,izbranProfil]).fetchall()
		i = 0
		self.skenString = []
		for sekcija in self.scanimageOpcije:
			for nastavitev in sekcija[1:]:
				if nastavitev[1] != nastavitve[i][1]:
					if "=" == nastavitev[0][-1]:
						self.skenString.append(nastavitve[i][0] + nastavitve[i][1])
					else:
						self.skenString.append(nastavitve[i][0])
						self.skenString.append(nastavitve[i][1])
				i += 1

baza = None
uporabnik = ""
aktiven = False
administrator = True
skenira = False
spisekDokumentov = {}
program = QtGui.QApplication(sys.argv)
glavnoOkno = GlavnoOkno()
glavnoOkno.show()
program.exec_()
baza.close()
